from typing import overload
from .Pos2D import Pos2D
from .Draw3D import Draw3D
from .EntityHelper import EntityHelper
from .EntityTraceLine import EntityTraceLine


class EntityTraceLine_Builder:
	screenPos: Pos2D

	@overload
	def __init__(self, parent: Draw3D) -> None:
		pass

	@overload
	def entity(self, entity: EntityHelper) -> "EntityTraceLine_Builder":
		"""
		Since: 1.9.0 

		Args:
			entity: the target entity 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def getEntity(self) -> EntityHelper:
		"""
		Since: 1.9.0 

		Returns:
			the target entity 
		"""
		pass

	@overload
	def yOffset(self, yOffset: float) -> "EntityTraceLine_Builder":
		"""
		Since: 1.9.0 

		Args:
			yOffset: the offset of y-axis 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def getYOffset(self) -> float:
		"""
		Since: 1.9.0 

		Returns:
			the offset of y-axis 
		"""
		pass

	@overload
	def color(self, color: int) -> "EntityTraceLine_Builder":
		"""
		Since: 1.9.0 

		Args:
			color: the color of the line 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def color(self, color: int, alpha: int) -> "EntityTraceLine_Builder":
		"""
		Since: 1.9.0 

		Args:
			color: the color of the line 
			alpha: the alpha value of the line's color 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def color(self, r: int, g: int, b: int) -> "EntityTraceLine_Builder":
		"""
		Since: 1.9.0 

		Args:
			r: the red component of the color 
			b: the blue component of the color 
			g: the green component of the color 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def color(self, r: int, g: int, b: int, a: int) -> "EntityTraceLine_Builder":
		"""
		Since: 1.9.0 

		Args:
			a: the alpha value of the color 
			r: the red component of the color 
			b: the blue component of the color 
			g: the green component of the color 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def getColor(self) -> int:
		"""
		Since: 1.9.0 

		Returns:
			the color of the line 
		"""
		pass

	@overload
	def alpha(self, alpha: int) -> "EntityTraceLine_Builder":
		"""
		Since: 1.9.0 

		Args:
			alpha: the alpha value for the line's color 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def getAlpha(self) -> int:
		"""
		Since: 1.9.0 

		Returns:
			the alpha value of the line's color 
		"""
		pass

	@overload
	def buildAndAdd(self, entity: EntityHelper) -> EntityTraceLine:
		"""Creates the trace line for the given values and adds it to the draw3D\n
		Since: 1.9.0 

		Args:
			entity: the target entity 

		Returns:
			the build line 
		"""
		pass

	@overload
	def buildAndAdd(self) -> EntityTraceLine:
		"""Creates the trace line for the given values and adds it to the draw3D\n
		Since: 1.9.0 

		Returns:
			the build line 
		"""
		pass

	@overload
	def build(self, entity: EntityHelper) -> EntityTraceLine:
		"""Builds the line from the given values\n
		Since: 1.9.0 

		Args:
			entity: the target entity 

		Returns:
			the build line 
		"""
		pass

	@overload
	def build(self) -> EntityTraceLine:
		"""Builds the line from the given values\n
		Since: 1.9.0 

		Returns:
			the build line 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar

java_util_function_Consumer_xyz_wagyourtail_jsmacros_client_api_classes_InteractionProxy_Break_BreakBlockResult_ = TypeVar("java_util_function_Consumer_xyz_wagyourtail_jsmacros_client_api_classes_InteractionProxy_Break_BreakBlockResult_")
Consumer = java_util_function_Consumer_xyz_wagyourtail_jsmacros_client_api_classes_InteractionProxy_Break_BreakBlockResult_

net_minecraft_util_math_BlockPos = TypeVar("net_minecraft_util_math_BlockPos")
BlockPos = net_minecraft_util_math_BlockPos


class InteractionProxy_Break:

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def setOverride(self, value: bool) -> None:
		pass

	@overload
	def setOverride(self, value: bool, reason: str) -> None:
		pass

	@overload
	def addCallback(self, callback: Consumer, breaking: bool) -> None:
		pass

	@overload
	def isBreaking(self) -> bool:
		pass

	@overload
	def onBreakBlock(self, pos: BlockPos, ret: bool) -> None:
		pass

	pass





from typing import overload
from typing import List
from .BaseEvent import BaseEvent
from .Pos3D import Pos3D


class EventSignEdit(BaseEvent):
	"""
	Since: 1.2.7 
	"""
	pos: Pos3D
	closeScreen: bool
	signText: List[str]

	@overload
	def __init__(self, signText: List[str], x: int, y: int, z: int) -> None:
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from typing import Set

io_noties_prism4j_Prism4j_Grammar = TypeVar("io_noties_prism4j_Prism4j_Grammar")
Prism4j_Grammar = io_noties_prism4j_Prism4j_Grammar

io_noties_prism4j_Prism4j_Node = TypeVar("io_noties_prism4j_Prism4j_Node")
Prism4j_Node = io_noties_prism4j_Prism4j_Node

io_noties_prism4j_GrammarLocator = TypeVar("io_noties_prism4j_GrammarLocator")
GrammarLocator = io_noties_prism4j_GrammarLocator

io_noties_prism4j_Prism4j = TypeVar("io_noties_prism4j_Prism4j")
Prism4j = io_noties_prism4j_Prism4j


class Prism(GrammarLocator):

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def getNodes(self, text: str, language: str) -> List[Prism4j_Node]:
		pass

	@overload
	def grammar(self, prism4j: Prism4j, language: str) -> Prism4j_Grammar:
		pass

	@overload
	def languages(self) -> Set[str]:
		pass

	pass





from typing import overload
from .BaseEvent import BaseEvent


class EventFallFlying(BaseEvent):
	state: bool

	@overload
	def __init__(self, state: bool) -> None:
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from .ISignEditScreen import ISignEditScreen


class MixinSignEditScreen(ISignEditScreen):

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def jsmacros_setLine(self, line: int, text: str) -> None:
		pass

	pass





from typing import TypeVar

from .EventContainer import EventContainer
from .BaseEvent import BaseEvent
from .TraceLine_Builder import TraceLine_Builder
from .GroupFilter_CountMatchFilter import GroupFilter_CountMatchFilter
from .Registrable import Registrable
from .Util import Util
from .History import History
from .OptionsField import OptionsField
from .Vec3D import Vec3D
from .TextOverlay import TextOverlay
from .CharCompareFilter import CharCompareFilter
from .LongField import LongField
from .CommandManager import CommandManager
from .IRecipeBookResults import IRecipeBookResults
from .RecipeInventory import RecipeInventory
from .Button import Button
from .Sorting_SortServiceByFileName import Sorting_SortServiceByFileName
from .IDraw2D import IDraw2D
from .DataGen import DataGen
from .TextInput import TextInput
from .Prism_typescript import Prism_typescript
from .DoubleField import DoubleField
from .InteractionProxy_Break_BreakBlockResult import InteractionProxy_Break_BreakBlockResult
from .BaseScriptContext_ScriptAssertionError import BaseScriptContext_ScriptAssertionError
from .IChunkSection import IChunkSection
from .Rect import Rect
from .InteractionProxy import InteractionProxy
from .TraceLine import TraceLine
from .FiltererComposed import FiltererComposed
from .RenderElement3D import RenderElement3D
from .IItemCooldownManager import IItemCooldownManager
from .ClientConfigV2 import ClientConfigV2
from .Prism_groovy import Prism_groovy
from .ColorMapSetting import ColorMapSetting
from .Vec2D import Vec2D
from .Line3D import Line3D
from .IPalettedContainer import IPalettedContainer
from .ColorMapSetting_ColorEntry import ColorMapSetting_ColorEntry
from .PlayerInput import PlayerInput
from .IFontManager import IFontManager
from .Line import Line
from .IRecipeBookWidget import IRecipeBookWidget
from .IBeaconScreen import IBeaconScreen
from .StringifyFilter import StringifyFilter
from .IHorseScreen import IHorseScreen
from .WrappedClassInstance_MethodSigParts import WrappedClassInstance_MethodSigParts
from .IFilter import IFilter
from .IPackedIntegerArray import IPackedIntegerArray
from .ChatHistoryManager import ChatHistoryManager
from .Inventory import Inventory
from .Line3D_Builder import Line3D_Builder
from .Sorting_SortByTriggerName import Sorting_SortByTriggerName
from .BaseWrappedException_HostLocation import BaseWrappedException_HostLocation
from .TranslationUtil import TranslationUtil
from .IntField import IntField
from .BaseListener import BaseListener
from .Surface import Surface
from .AutoCompleteSuggester import AutoCompleteSuggester
from .AbstractSettingContainer import AbstractSettingContainer
from .SelectorDropdownOverlay import SelectorDropdownOverlay
from .FileChooser_fileObj import FileChooser_fileObj
from .ServiceContainer import ServiceContainer
from .BlockStateFilter import BlockStateFilter
from .EnchantInventory import EnchantInventory
from .IMerchantScreen import IMerchantScreen
from .KeyMacrosScreen import KeyMacrosScreen
from .Rect_Builder import Rect_Builder
from .ClassBuilder_ConstructorBuilder import ClassBuilder_ConstructorBuilder
from .History_TabLinesKeepCursor import History_TabLinesKeepCursor
from .History_HistoryStep import History_HistoryStep
from .AbstractMapSettingContainer_MapSettingEntry import AbstractMapSettingContainer_MapSettingEntry
from .Scrollbar import Scrollbar
from .BooleanCompareFilter import BooleanCompareFilter
from .History_Add import History_Add
from .FileChooser_sortFile import FileChooser_sortFile
from .CraftingInventory import CraftingInventory
from .EventRegistry import EventRegistry
from .EventFilterer import EventFilterer
from .Websocket import Websocket
from .ScriptTrigger import ScriptTrigger
from .Plane3D import Plane3D
from .Sorting_SortServiceByRunning import Sorting_SortServiceByRunning
from .DocletDeclareType import DocletDeclareType
from .StoneCutterInventory import StoneCutterInventory
from .AbstractWidgetBuilder import AbstractWidgetBuilder
from .ServiceListTopbar import ServiceListTopbar
from .TickSync_TickSyncInt import TickSync_TickSyncInt
from .CustomImage import CustomImage
from .IClientPlayerInteractionManager import IClientPlayerInteractionManager
from .Event import Event
from .KeyListener import KeyListener
from .BrewingStandInventory import BrewingStandInventory
from .BasicFilter import BasicFilter
from .ExtensionLoader import ExtensionLoader
from .VillagerInventory import VillagerInventory
from .CartographyInventory import CartographyInventory
from .BaseWrappedException import BaseWrappedException
from .PerExecLanguageLibrary import PerExecLanguageLibrary
from .Box_Builder import Box_Builder
from .NumberCompareFilter import NumberCompareFilter
from .SettingsOverlay_SettingField import SettingsOverlay_SettingField
from .ClassBuilder import ClassBuilder
from .CustomClickEvent import CustomClickEvent
from .TextBuilder import TextBuilder
from .FiltererBlockUpdate import FiltererBlockUpdate
from .IContainerParent import IContainerParent
from .StringMapSetting_StringEntry import StringMapSetting_StringEntry
from .BaseWrappedException_GuestLocation import BaseWrappedException_GuestLocation
from .FileChooser import FileChooser
from .Sorting_SortByEnabled import Sorting_SortByEnabled
from .Draw2DElement import Draw2DElement
from .Item_Builder import Item_Builder
from .FakeServerCommandSource import FakeServerCommandSource
from .InteractionProxy_Break import InteractionProxy_Break
from .PrimitiveSettingGroup import PrimitiveSettingGroup
from .LibraryBuilder import LibraryBuilder
from .Draw3D import Draw3D
from .Prism_kotlin import Prism_kotlin
from .FReflection_CombinedVariableClassLoader import FReflection_CombinedVariableClassLoader
from .TickSync import TickSync
from .ModLoader import ModLoader
from .EventChooser_EventObj import EventChooser_EventObj
from .Image_Builder import Image_Builder
from .StringField import StringField
from .BaseScriptContext_SleepRunnable import BaseScriptContext_SleepRunnable
from .MovementDummy import MovementDummy
from .IOverlayParent import IOverlayParent
from .Slider import Slider
from .ScriptScreen import ScriptScreen
from .IMinecraftClient import IMinecraftClient
from .WorldScannerBuilder import WorldScannerBuilder
from .Draw2D import Draw2D
from .FloatField import FloatField
from .StringMapSetting import StringMapSetting
from .FJsMacros_EventAndContext import FJsMacros_EventAndContext
from .Sorting_MacroSortMethod import Sorting_MacroSortMethod
from .CancelScreen_RTCSort import CancelScreen_RTCSort
from .NoStyleCodeCompiler import NoStyleCodeCompiler
from .AboutOverlay import AboutOverlay
from .CheckBoxContainer import CheckBoxContainer
from .IResourcePackManager import IResourcePackManager
from .ListContainer import ListContainer
from .DocletReplaceParams import DocletReplaceParams
from .PerLanguageLibrary import PerLanguageLibrary
from .BaseScriptContext import BaseScriptContext
from .Extension_ExtMatch import Extension_ExtMatch
from .NameUtil import NameUtil
from .Pair import Pair
from .ProxyBuilder import ProxyBuilder
from .IInventory import IInventory
from .IScreen import IScreen
from .TextPrompt import TextPrompt
from .Prism_json import Prism_json
from .FileHandler_FileLineIterator import FileHandler_FileLineIterator
from .ServiceScreen import ServiceScreen
from .CreativeInventory import CreativeInventory
from .ClassBuilder_FieldBuilder import ClassBuilder_FieldBuilder
from .Extension import Extension
from .Surface_Builder import Surface_Builder
from .ClassBuilder_AnnotationBuilder_AnnotationArrayBuilder import ClassBuilder_AnnotationBuilder_AnnotationArrayBuilder
from .Line_Builder import Line_Builder
from .Mappings import Mappings
from .BaseLibrary import BaseLibrary
from .ICategoryTreeParent import ICategoryTreeParent
from .ServiceTrigger import ServiceTrigger
from .WrappedScript import WrappedScript
from .StringCompareFilter_FilterMethod import StringCompareFilter_FilterMethod
from .CommandNodeAccessor import CommandNodeAccessor
from .PrioryFiFoTaskQueue import PrioryFiFoTaskQueue
from .RenderElement import RenderElement
from .EventFilterer_Compound import EventFilterer_Compound
from .ClassWrapperFilter import ClassWrapperFilter
from .ContainerInventory import ContainerInventory
from .Text_Builder import Text_Builder
from .Image import Image
from .Sorting_ServiceSortMethod import Sorting_ServiceSortMethod
from .RenderElementBuilder import RenderElementBuilder
from .Item import Item
from .IMerchantEntity import IMerchantEntity
from .HorseInventory import HorseInventory
from .WorldScanner import WorldScanner
from .DefaultCodeCompiler import DefaultCodeCompiler
from .Pos2D import Pos2D
from .BlockFilter import BlockFilter
from .FiltererModulus import FiltererModulus
from .HTTPRequest import HTTPRequest
from .ISignEditScreen import ISignEditScreen
from .FileField import FileField
from .OrFilter import OrFilter
from .FKeyBind_KeyTracker import FKeyBind_KeyTracker
from .FiltererInverted import FiltererInverted
from .IAdvancedFilter import IAdvancedFilter
from .LibraryRegistry import LibraryRegistry
from .TickBasedEvents import TickBasedEvents
from .ILoomScreen import ILoomScreen
from .NotFilter import NotFilter
from .SettingsOverlay import SettingsOverlay
from .BaseWrappedException_SourceLocation import BaseWrappedException_SourceLocation
from .HTTPRequest_Response import HTTPRequest_Response
from .FiltererRecvPacket import FiltererRecvPacket
from .Prism_python import Prism_python
from .Pos3D import Pos3D
from .MacroScreen import MacroScreen
from .IScreenInternal import IScreenInternal
from .ExtensionClassLoader import ExtensionClassLoader
from .ICompare import ICompare
from .ConfigFolder import ConfigFolder
from .IBossBarHud import IBossBarHud
from .History_TabLines import History_TabLines
from .Mappings_MethodData import Mappings_MethodData
from .Profile import Profile
from .BaseEventRegistry import BaseEventRegistry
from .GroupFilter_NoneMatchFilter import GroupFilter_NoneMatchFilter
from .MacroListTopbar import MacroListTopbar
from .BooleanField import BooleanField
from .Prism_regex import Prism_regex
from .IPlayerListHud import IPlayerListHud
from .AnvilInventory import AnvilInventory
from .Prism_lua import Prism_lua
from .ClassBuilder_FieldBuilder_FieldInitializerBuilder import ClassBuilder_FieldBuilder_FieldInitializerBuilder
from .EventListener import EventListener
from .BaseProfile import BaseProfile
from .GrindStoneInventory import GrindStoneInventory
from .TPSData import TPSData
from .ConfirmOverlay import ConfirmOverlay
from .SynchronizedWeakHashSet import SynchronizedWeakHashSet
from .GroupFilter import GroupFilter
from .Neighbor import Neighbor
from .Text import Text
from .SmithingInventory import SmithingInventory
from .StringHashTrie import StringHashTrie
from .ConfigManager import ConfigManager
from .Sorting_SortServiceByName import Sorting_SortServiceByName
from .EventLockWatchdog import EventLockWatchdog
from .AndFilter import AndFilter
from .OverlayContainer import OverlayContainer
from .Alignable import Alignable
from .AbstractMapSettingContainer import AbstractMapSettingContainer
from .BaseLanguage import BaseLanguage
from .Mappings_ClassData import Mappings_ClassData
from .CategoryTreeContainer import CategoryTreeContainer
from .MultiElementContainer import MultiElementContainer
from .BeaconInventory import BeaconInventory
from .AutoCompleteSuggestion import AutoCompleteSuggestion
from .AnnotatedCheckBox import AnnotatedCheckBox
from .FiltererSendPacket import FiltererSendPacket
from .MacroContainer import MacroContainer
from .InteractionProxy_Target import InteractionProxy_Target
from .Sorting_SortServiceByEnabled import Sorting_SortServiceByEnabled
from .ProxyBuilder_ProxyReference import ProxyBuilder_ProxyReference
from .JsMacrosThreadPool_PoolThread import JsMacrosThreadPool_PoolThread
from .IChatHud import IChatHud
from .History_Replace import History_Replace
from .EntityTraceLine import EntityTraceLine
from .DocletIgnore import DocletIgnore
from .GroupFilter_AllMatchFilter import GroupFilter_AllMatchFilter
from .XorFilter import XorFilter
from .ScriptTrigger_TriggerType import ScriptTrigger_TriggerType
from .StringCompareFilter import StringCompareFilter
from .EditorScreen import EditorScreen
from .Sorting_SortByFileName import Sorting_SortByFileName
from .BaseScreen import BaseScreen
from .IItemCooldownEntry import IItemCooldownEntry
from .Prism_ruby import Prism_ruby
from .JsMacros import JsMacros
from .EventMacrosScreen import EventMacrosScreen
from .Core import Core
from .CoreConfigV2 import CoreConfigV2
from .SelectCursor import SelectCursor
from .History_Remove import History_Remove
from .Websocket_Disconnected import Websocket_Disconnected
from .Prism_javascript import Prism_javascript
from .Box import Box
from .DocletReplaceTypeParams import DocletReplaceTypeParams
from .AbstractSettingField import AbstractSettingField
from .DocletReplaceReturn import DocletReplaceReturn
from .Option import Option
from .Library import Library
from .ClassBuilder_MethodBuilder import ClassBuilder_MethodBuilder
from .MethodWrapper import MethodWrapper
from .Prism import Prism
from .ProfileSetting import ProfileSetting
from .InteractionProxy_Interact import InteractionProxy_Interact
from .FileMapSetting import FileMapSetting
from .FileMapSetting_FileEntry import FileMapSetting_FileEntry
from .WrappedClassInstance import WrappedClassInstance
from .Mappings_MappedClass import Mappings_MappedClass
from .FJsMacros_ScriptEventListener import FJsMacros_ScriptEventListener
from .LoomInventory import LoomInventory
from .ServiceManager_ServiceStatus import ServiceManager_ServiceStatus
from .CancelScreen import CancelScreen
from .GroupFilter_AnyMatchFilter import GroupFilter_AnyMatchFilter
from .EntityTraceLine_Builder import EntityTraceLine_Builder
from .PerExecLibrary import PerExecLibrary
from .AbstractRenderCodeCompiler import AbstractRenderCodeCompiler
from .ServiceManager import ServiceManager
from .JsMacrosThreadPool import JsMacrosThreadPool
from .MovementQueue import MovementQueue
from .EventChooser import EventChooser
from .OptionType import OptionType
from .EventContainer import EventContainer
from .BaseEvent import BaseEvent
from .PlayerInventory import PlayerInventory
from .TextStyleCompiler import TextStyleCompiler
from .Sorting import Sorting
from .FileHandler import FileHandler
from .ProfileSetting_ProfileEntry import ProfileSetting_ProfileEntry
from .IEventListener import IEventListener
from .Prism_clike import Prism_clike
from .FurnaceInventory import FurnaceInventory
from .IPalettedContainerData import IPalettedContainerData
from .ClassBuilder_BodyBuilder import ClassBuilder_BodyBuilder
from .History_ShiftLine import History_ShiftLine
from .ClassBuilder_AnnotationBuilder import ClassBuilder_AnnotationBuilder
from .BossBarConsumer import BossBarConsumer
from .ScriptCodeCompiler import ScriptCodeCompiler
from .CommandBuilder import CommandBuilder
from .Draw2DElement_Builder import Draw2DElement_Builder
from .RunningContextContainer import RunningContextContainer

File = TypeVar("java.io.File")




from typing import overload
from typing import List
from .ClassBuilder import ClassBuilder
from .ClassBuilder_ConstructorBuilder import ClassBuilder_ConstructorBuilder


class LibraryBuilder(ClassBuilder):
	"""
	Since: 1.6.5 
	"""

	@overload
	def __init__(self, name: str, perExec: bool, allowedLangs: List[str]) -> None:
		pass

	@overload
	def addConstructor(self) -> ClassBuilder_ConstructorBuilder:
		"""constructor, if perExec run every context, if per language run once for each lang;
params are context and language class.
if not per exec, param will be skipped.
ie:
BaseLibrary: no params
PerExecLibrary: context
PerExecLanguageLibrary: context, language
PerLanguageLibrary: language 
Don't do other constructors...
		"""
		pass

	@overload
	def finishBuildAndFreeze(self) -> Class:
		pass

	pass





from typing import overload
from typing import TypeVar

java_util_function_Supplier_java_lang_String_ = TypeVar("java_util_function_Supplier_java_lang_String_")
Supplier = java_util_function_Supplier_java_lang_String_


class Mappings_MethodData:
	name: str
	sig: Supplier

	@overload
	def __init__(self, name: str, sig: Supplier) -> None:
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar
from .MultiElementContainer import MultiElementContainer
from .ScriptTrigger import ScriptTrigger
from .MacroScreen import MacroScreen

net_minecraft_client_gui_DrawContext = TypeVar("net_minecraft_client_gui_DrawContext")
DrawContext = net_minecraft_client_gui_DrawContext

net_minecraft_text_Text = TypeVar("net_minecraft_text_Text")
Text = net_minecraft_text_Text

java_io_File = TypeVar("java_io_File")
File = java_io_File

net_minecraft_client_font_TextRenderer = TypeVar("net_minecraft_client_font_TextRenderer")
TextRenderer = net_minecraft_client_font_TextRenderer


class MacroContainer(MultiElementContainer):

	@overload
	def __init__(self, x: int, y: int, width: int, height: int, textRenderer: TextRenderer, macro: ScriptTrigger, parent: MacroScreen) -> None:
		pass

	@overload
	def getRawMacro(self) -> ScriptTrigger:
		pass

	@overload
	def init(self) -> None:
		pass

	@overload
	def setEventType(self, type: str) -> None:
		pass

	@overload
	def setFile(self, f: File) -> None:
		pass

	@overload
	def setPos(self, x: int, y: int, width: int, height: int) -> None:
		pass

	@overload
	def onKey(self, translationKey: str) -> bool:
		pass

	@overload
	def buildKeyName(self, translationKeys: str) -> Text:
		pass

	@overload
	def setKey(self, translationKeys: str) -> None:
		pass

	@overload
	def render(self, drawContext: DrawContext, mouseX: int, mouseY: int, delta: float) -> None:
		pass

	pass





from typing import overload
from .Alignable import Alignable
from .RenderElementBuilder import RenderElementBuilder
from .IDraw2D import IDraw2D
from .ItemStackHelper import ItemStackHelper


class Item_Builder(Alignable, RenderElementBuilder):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, draw2D: IDraw2D) -> None:
		pass

	@overload
	def x(self, x: int) -> "Item_Builder":
		"""
		Since: 1.8.4 

		Args:
			x: the x position of the item 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getX(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the x position of the item. 
		"""
		pass

	@overload
	def y(self, y: int) -> "Item_Builder":
		"""
		Since: 1.8.4 

		Args:
			y: the y position of the item 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getY(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the y position of the item. 
		"""
		pass

	@overload
	def pos(self, x: int, y: int) -> "Item_Builder":
		"""
		Since: 1.8.4 

		Args:
			x: the x position of the item 
			y: the y position of the item 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def item(self, item: ItemStackHelper) -> "Item_Builder":
		"""
		Since: 1.8.4 

		Args:
			item: the item to draw 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def item(self, id: str) -> "Item_Builder":
		"""
		Since: 1.8.4 

		Args:
			id: the id of the item to draw 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def item(self, id: str, count: int) -> "Item_Builder":
		"""
		Since: 1.8.4 

		Args:
			count: the stack size 
			id: the id of the item to draw 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getItem(self) -> ItemStackHelper:
		"""
		Since: 1.8.4 

		Returns:
			the item to be drawn. 
		"""
		pass

	@overload
	def overlayText(self, overlayText: str) -> "Item_Builder":
		"""This also sets the overlay to be shown.\n
		Since: 1.8.4 

		Args:
			overlayText: the overlay text 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getOverlayText(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the overlay text. 
		"""
		pass

	@overload
	def overlayVisible(self, visible: bool) -> "Item_Builder":
		"""
		Since: 1.8.4 

		Args:
			visible: whether the overlay should be visible or not 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def isOverlayVisible(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the overlay should be visible, 'false' otherwise. 
		"""
		pass

	@overload
	def scale(self, scale: float) -> "Item_Builder":
		"""
		Since: 1.8.4 

		Args:
			scale: the scale of the item 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getScale(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the scale of the item. 
		"""
		pass

	@overload
	def rotation(self, rotation: float) -> "Item_Builder":
		"""
		Since: 1.8.4 

		Args:
			rotation: the rotation (clockwise) of the item in degrees 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getRotation(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the rotation (clockwise) of the item in degrees. 
		"""
		pass

	@overload
	def rotateCenter(self, rotateCenter: bool) -> "Item_Builder":
		"""
		Since: 1.8.4 

		Args:
			rotateCenter: whether the item should be rotated around its center 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def isRotatingCenter(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this item should be rotated around its center, 'false' otherwise. 
		"""
		pass

	@overload
	def zIndex(self, zIndex: int) -> "Item_Builder":
		"""
		Since: 1.8.4 

		Args:
			zIndex: the z-index of the item 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getZIndex(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the z-index of the item. 
		"""
		pass

	@overload
	def getScaledWidth(self) -> int:
		pass

	@overload
	def getParentWidth(self) -> int:
		pass

	@overload
	def getScaledHeight(self) -> int:
		pass

	@overload
	def getParentHeight(self) -> int:
		pass

	@overload
	def getScaledLeft(self) -> int:
		pass

	@overload
	def getScaledTop(self) -> int:
		pass

	@overload
	def moveTo(self, x: int, y: int) -> "Item_Builder":
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from typing import Mapping
from typing import Generic
from .ItemStackHelper import ItemStackHelper
from .Pos2D import Pos2D

T = TypeVar("T")
net_minecraft_client_gui_screen_Screen = TypeVar("net_minecraft_client_gui_screen_Screen")
Screen = net_minecraft_client_gui_screen_Screen


class Inventory(Generic[T]):
	"""
	Since: 1.0.8 
	"""

	@overload
	def create(self) -> "Inventory":
		pass

	@overload
	def create(self, s: Screen) -> "Inventory":
		pass

	@overload
	def click(self, slot: int) -> "Inventory":
		"""
		Since: 1.5.0 

		Args:
			slot: 
		"""
		pass

	@overload
	def click(self, slot: int, mousebutton: int) -> "Inventory":
		"""Clicks a slot with a mouse button.~~if the slot is a container, it will click the first slot in the container\n
		Since: 1.0.8 

		Args:
			mousebutton: 
			slot: 
		"""
		pass

	@overload
	def dragClick(self, slots: List[int], mousebutton: int) -> "Inventory":
		"""Does a drag-click with a mouse button. (the slots don't have to be in order or even adjacent, but when vanilla minecraft calls the underlying function they're always sorted...)

		Args:
			slots: 
			mousebutton: 
		"""
		pass

	@overload
	def dropSlot(self, slot: int) -> "Inventory":
		"""
		Since: 1.5.0 

		Args:
			slot: 
		"""
		pass

	@overload
	def dropSlot(self, slot: int, stack: bool) -> "Inventory":
		"""
		Since: 1.8.4 

		Args:
			stack: decide whether to drop the whole stack or just a single item 
			slot: the slot to drop 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def contains(self, item: ItemStackHelper) -> bool:
		"""
		Since: 1.8.4 

		Args:
			item: the item to check for 

		Returns:
			'true' if the item is contined anywhere in the inventory, 'false' otherwise. 
		"""
		pass

	@overload
	def contains(self, item: str) -> bool:
		"""
		Since: 1.8.4 

		Args:
			item: the item to check for 

		Returns:
			'true' if the item is contined anywhere in the inventory, 'false' otherwise. 
		"""
		pass

	@overload
	def findFreeInventorySlot(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the first empty slot in the main inventory or '-1' if there are no empty
slots. 
		"""
		pass

	@overload
	def findFreeHotbarSlot(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the first empty hotbar slot or '-1' if there are no empty slots. 
		"""
		pass

	@overload
	def findFreeSlot(self, mapIdentifiers: List[str]) -> int:
		"""
		Since: 1.8.4 

		Args:
			mapIdentifiers: the identifier of the inventory sections to check 

		Returns:
			the first empty slot in the given inventory sections, or '-1' if there are no
empty slots. 
		"""
		pass

	@overload
	def getItemCount(self) -> Mapping[str, int]:
		"""
		Since: 1.8.4 

		Returns:
			a map of all item ids and their total count inside the inventory. 
		"""
		pass

	@overload
	def getItems(self) -> List[ItemStackHelper]:
		"""
		Since: 1.8.4 

		Returns:
			a list of all items in the inventory. 
		"""
		pass

	@overload
	def getItems(self, mapIdentifiers: List[str]) -> List[ItemStackHelper]:
		"""
		Since: 1.8.4 

		Args:
			mapIdentifiers: the inventory sections 

		Returns:
			a list of all items in the given inventory sections. 
		"""
		pass

	@overload
	def findItem(self, item: ItemStackHelper) -> List[int]:
		"""
		Since: 1.8.4 

		Args:
			item: the item to search for 

		Returns:
			all slots containing the given item. 
		"""
		pass

	@overload
	def findItem(self, item: str) -> List[int]:
		"""
		Since: 1.8.4 

		Args:
			item: the item to search for 

		Returns:
			all slots containing the given item. 
		"""
		pass

	@overload
	def getSlots(self, mapIdentifiers: List[str]) -> List[int]:
		"""
		Since: 1.8.4 

		Args:
			mapIdentifiers: the inventory sections 

		Returns:
			all slots indexes in the given inventory sections. 
		"""
		pass

	@overload
	def getSelectedHotbarSlotIndex(self) -> int:
		"""
		Since: 1.2.5 

		Returns:
			the index of the selected hotbar slot. 
		"""
		pass

	@overload
	def setSelectedHotbarSlotIndex(self, index: int) -> None:
		"""
		Since: 1.2.5 

		Args:
			index: 
		"""
		pass

	@overload
	def closeAndDrop(self) -> "Inventory":
		"""closes the inventory, (if the inventory/container is visible it will close the gui). also drops any "held on mouse" items.
		"""
		pass

	@overload
	def close(self) -> None:
		"""Closes the inventory, and open gui if applicable.
		"""
		pass

	@overload
	def quick(self, slot: int) -> "Inventory":
		"""simulates a shift-click on a slot.
It should be safe to chain these without FClient#waitTick() at least for a bunch of the same item.

		Args:
			slot: 
		"""
		pass

	@overload
	def quickAll(self, slot: int) -> int:
		"""
		Since: 1.7.0 

		Args:
			slot: 
		"""
		pass

	@overload
	def quickAll(self, slot: int, button: int) -> int:
		"""quicks all that match the slot\n
		Since: 1.7.0 

		Args:
			button: 
			slot: a slot from the section you want to move items from 

		Returns:
			number of items that matched 
		"""
		pass

	@overload
	def getHeld(self) -> ItemStackHelper:
		"""

		Returns:
			the held (by the mouse) item. 
		"""
		pass

	@overload
	def getSlot(self, slot: int) -> ItemStackHelper:
		"""

		Args:
			slot: 

		Returns:
			the item in the slot. 
		"""
		pass

	@overload
	def getTotalSlots(self) -> int:
		"""

		Returns:
			the size of the container/inventory. 
		"""
		pass

	@overload
	def split(self, slot1: int, slot2: int) -> "Inventory":
		"""Splits the held stack into two slots. can be alternatively done with Inventory#dragClick(int[],int) if this one has issues on some servers.

		Args:
			slot2: 
			slot1: 
		"""
		pass

	@overload
	def grabAll(self, slot: int) -> "Inventory":
		"""Does that double click thingy to turn a incomplete stack pickup into a complete stack pickup if you have more in your inventory.

		Args:
			slot: 
		"""
		pass

	@overload
	def swap(self, slot1: int, slot2: int) -> "Inventory":
		"""swaps the items in two slots.

		Args:
			slot2: 
			slot1: 
		"""
		pass

	@overload
	def swapHotbar(self, slot: int, hotbarSlot: int) -> "Inventory":
		"""equivalent to hitting the numbers or f for swapping slots to hotbar\n
		Since: 1.6.5 [citation needed] 

		Args:
			hotbarSlot: 0-8 or 40 for offhand 
			slot: 
		"""
		pass

	@overload
	def openGui(self) -> None:
		"""
		Since: 1.2.8 
		"""
		pass

	@overload
	def getSlotUnderMouse(self) -> int:
		"""
		Since: 1.1.3 

		Returns:
			the id of the slot under the mouse. 
		"""
		pass

	@overload
	def getType(self) -> str:
		"""
		Since: 1.1.3 

		Returns:
			the part of the mapping the slot is in. 
		"""
		pass

	@overload
	def is_(self, types: List[str]) -> bool:
		"""checks if this inventory type equals to any of the specified types\n
		Since: 1.9.0 
		"""
		pass

	@overload
	def getMap(self) -> Mapping[str, List[int]]:
		"""
		Since: 1.1.3 

		Returns:
			the inventory mappings different depending on the type of open container/inventory. 
		"""
		pass

	@overload
	def getLocation(self, slotNum: int) -> str:
		"""
		Since: 1.1.3 

		Args:
			slotNum: 

		Returns:
			returns the part of the mapping the slot is in. 
		"""
		pass

	@overload
	def getSlotPos(self, slot: int) -> Pos2D:
		"""
		Since: 1.8.4 

		Returns:
			the x/y position of the specified slot index 
		"""
		pass

	@overload
	def isContainer(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the inventory is a container, 'false' otherwise. 
		"""
		pass

	@overload
	def getContainerTitle(self) -> str:
		"""
		Since: 1.2.3 
		"""
		pass

	@overload
	def getRawContainer(self) -> T:
		pass

	@overload
	def toString(self) -> str:
		pass

	@overload
	def getCurrentSyncId(self) -> int:
		"""
		Since: 1.6.0 
		"""
		pass

	pass





from typing import overload
from typing import List
from .Registrable import Registrable
from .MethodWrapper import MethodWrapper
from .BlockPosHelper import BlockPosHelper


class CommandBuilder(Registrable):
	"""
	Since: 1.4.2 
	"""

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def literalArg(self, name: str) -> "CommandBuilder":
		pass

	@overload
	def booleanArg(self, name: str) -> "CommandBuilder":
		pass

	@overload
	def intArg(self, name: str) -> "CommandBuilder":
		pass

	@overload
	def intArg(self, name: str, min: int, max: int) -> "CommandBuilder":
		pass

	@overload
	def intRangeArg(self, name: str) -> "CommandBuilder":
		pass

	@overload
	def longArg(self, name: str) -> "CommandBuilder":
		pass

	@overload
	def longArg(self, name: str, min: float, max: float) -> "CommandBuilder":
		pass

	@overload
	def floatRangeArg(self, name: str) -> "CommandBuilder":
		pass

	@overload
	def doubleArg(self, name: str) -> "CommandBuilder":
		pass

	@overload
	def doubleArg(self, name: str, min: float, max: float) -> "CommandBuilder":
		pass

	@overload
	def uuidArgType(self, name: str) -> "CommandBuilder":
		pass

	@overload
	def greedyStringArg(self, name: str) -> "CommandBuilder":
		pass

	@overload
	def quotedStringArg(self, name: str) -> "CommandBuilder":
		pass

	@overload
	def wordArg(self, name: str) -> "CommandBuilder":
		pass

	@overload
	def regexArgType(self, name: str, regex: str, flags: str) -> "CommandBuilder":
		pass

	@overload
	def textArgType(self, name: str) -> "CommandBuilder":
		pass

	@overload
	def timeArg(self, name: str) -> "CommandBuilder":
		pass

	@overload
	def identifierArg(self, name: str) -> "CommandBuilder":
		pass

	@overload
	def nbtArg(self, name: str) -> "CommandBuilder":
		pass

	@overload
	def nbtElementArg(self, name: str) -> "CommandBuilder":
		pass

	@overload
	def nbtCompoundArg(self, name: str) -> "CommandBuilder":
		pass

	@overload
	def colorArg(self, name: str) -> "CommandBuilder":
		pass

	@overload
	def angleArg(self, name: str) -> "CommandBuilder":
		pass

	@overload
	def itemArg(self, name: str) -> "CommandBuilder":
		pass

	@overload
	def itemStackArg(self, name: str) -> "CommandBuilder":
		pass

	@overload
	def itemPredicateArg(self, name: str) -> "CommandBuilder":
		pass

	@overload
	def blockArg(self, name: str) -> "CommandBuilder":
		pass

	@overload
	def blockStateArg(self, name: str) -> "CommandBuilder":
		pass

	@overload
	def blockPredicateArg(self, name: str) -> "CommandBuilder":
		pass

	@overload
	def blockPosArg(self, name: str) -> "CommandBuilder":
		pass

	@overload
	def columnPosArg(self, name: str) -> "CommandBuilder":
		pass

	@overload
	def dimensionArg(self, name: str) -> "CommandBuilder":
		pass

	@overload
	def itemSlotArg(self, name: str) -> "CommandBuilder":
		pass

	@overload
	def particleArg(self, name: str) -> "CommandBuilder":
		pass

	@overload
	def executes(self, callback: MethodWrapper) -> "CommandBuilder":
		"""it is recommended to use FJsMacros#runScript(java.lang.String,xyz.wagyourtail.jsmacros.core.event.BaseEvent) in the callback if you expect to actually do anything complicated with waits. 
the CommandContextHelper arg is an BaseEvent so you can pass it directly to FJsMacros#runScript(java.lang.String,xyz.wagyourtail.jsmacros.core.event.BaseEvent) . 
make sure your callback returns a boolean success = true.

		Args:
			callback: 
		"""
		pass

	@overload
	def suggestMatching(self, suggestions: List[str]) -> "CommandBuilder":
		"""
		Since: 1.6.5 

		Args:
			suggestions: 
		"""
		pass

	@overload
	def suggestMatching(self, suggestions: List[str]) -> "CommandBuilder":
		"""
		Since: 1.8.4 

		Args:
			suggestions: the strings to match 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def suggestIdentifier(self, suggestions: List[str]) -> "CommandBuilder":
		"""
		Since: 1.6.5 

		Args:
			suggestions: 
		"""
		pass

	@overload
	def suggestIdentifier(self, suggestions: List[str]) -> "CommandBuilder":
		"""
		Since: 1.8.4 

		Args:
			suggestions: the identifiers to match 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def suggestBlockPositions(self, positions: List[BlockPosHelper]) -> "CommandBuilder":
		"""
		Since: 1.8.4 

		Args:
			positions: the positions to suggest 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def suggestBlockPositions(self, positions: List[BlockPosHelper]) -> "CommandBuilder":
		"""
		Since: 1.8.4 

		Args:
			positions: the positions to suggest 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def suggestPositions(self, positions: List[str]) -> "CommandBuilder":
		"""Positions are strings of the form "x y z" where x, y, and z are numbers or the default
minecraft selectors "~" and "^" followed by a number.\n
		Since: 1.8.4 

		Args:
			positions: the positions to suggest 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def suggestPositions(self, positions: List[str]) -> "CommandBuilder":
		"""Positions are strings of the form "x y z" where x, y, and z are numbers or the default
minecraft selectors "~" and "^" followed by a number.\n
		Since: 1.8.4 

		Args:
			positions: the positions to match 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def suggest(self, callback: MethodWrapper) -> "CommandBuilder":
		"""
		Since: 1.6.5 

		Args:
			callback: 
		"""
		pass

	@overload
	def or_(self) -> "CommandBuilder":
		pass

	@overload
	def otherwise(self) -> "CommandBuilder":
		"""name overload for CommandBuilder#or() to work around language keyword restrictions\n
		Since: 1.5.2 
		"""
		pass

	@overload
	def or_(self, argumentLevel: int) -> "CommandBuilder":
		pass

	@overload
	def otherwise(self, argLevel: int) -> "CommandBuilder":
		"""name overload for CommandBuilder#or(int) to work around language keyword restrictions\n
		Since: 1.5.2 

		Args:
			argLevel: 
		"""
		pass

	@overload
	def register(self) -> "CommandBuilder":
		pass

	@overload
	def unregister(self) -> "CommandBuilder":
		"""
		Since: 1.6.5
removes this command 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar

java_lang_Runnable = TypeVar("java_lang_Runnable")
Runnable = java_lang_Runnable

java_lang_Thread = TypeVar("java_lang_Thread")
Thread = java_lang_Thread


class JsMacrosThreadPool_PoolThread(Thread):

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def runTask(self, task: Runnable) -> None:
		pass

	@overload
	def run(self) -> None:
		pass

	pass





from typing import overload
from .Alignable import Alignable
from .RenderElementBuilder import RenderElementBuilder
from .IDraw2D import IDraw2D
from .Draw2D import Draw2D


class Draw2DElement_Builder(Alignable, RenderElementBuilder):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, parent: IDraw2D, draw2D: Draw2D) -> None:
		pass

	@overload
	def x(self, x: int) -> "Draw2DElement_Builder":
		"""
		Since: 1.8.4 

		Args:
			x: the x position of the draw2D 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getX(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the x position of the draw2D. 
		"""
		pass

	@overload
	def y(self, y: int) -> "Draw2DElement_Builder":
		"""
		Since: 1.8.4 

		Args:
			y: the y position of the draw2D 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getY(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the y position of the draw2D. 
		"""
		pass

	@overload
	def pos(self, x: int, y: int) -> "Draw2DElement_Builder":
		"""
		Since: 1.8.4 

		Args:
			x: the x position of the draw2D 
			y: the y position of the draw2D 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def width(self, width: int) -> "Draw2DElement_Builder":
		"""
		Since: 1.8.4 

		Args:
			width: the width of the draw2D 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getWidth(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the width of the draw2D. 
		"""
		pass

	@overload
	def height(self, height: int) -> "Draw2DElement_Builder":
		"""
		Since: 1.8.4 

		Args:
			height: the height of the draw2D 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getHeight(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the height of the draw2D. 
		"""
		pass

	@overload
	def size(self, width: int, height: int) -> "Draw2DElement_Builder":
		"""
		Since: 1.8.4 

		Args:
			width: the width of the draw2D 
			height: the height of the draw2D 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def scale(self, scale: float) -> "Draw2DElement_Builder":
		"""
		Since: 1.8.4 

		Args:
			scale: the scale of the draw2D 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getScale(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the scale of the draw2D. 
		"""
		pass

	@overload
	def rotation(self, rotation: float) -> "Draw2DElement_Builder":
		"""
		Since: 1.8.4 

		Args:
			rotation: the rotation (clockwise) of the draw2D in degrees 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getRotation(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the rotation (clockwise) of the draw2D in degrees. 
		"""
		pass

	@overload
	def rotateCenter(self, rotateCenter: bool) -> "Draw2DElement_Builder":
		"""
		Since: 1.8.4 

		Args:
			rotateCenter: whether this draw2D should be rotated around its center 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def isRotatingCenter(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this draw2D should be rotated around its center, 'false' otherwise. 
		"""
		pass

	@overload
	def zIndex(self, zIndex: int) -> "Draw2DElement_Builder":
		"""
		Since: 1.8.4 

		Returns:
			the z-index of the draw2D. 
		"""
		pass

	@overload
	def getZIndex(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the z-index of the draw2D. 
		"""
		pass

	@overload
	def getScaledWidth(self) -> int:
		pass

	@overload
	def getParentWidth(self) -> int:
		pass

	@overload
	def getScaledHeight(self) -> int:
		pass

	@overload
	def getParentHeight(self) -> int:
		pass

	@overload
	def getScaledLeft(self) -> int:
		pass

	@overload
	def getScaledTop(self) -> int:
		pass

	@overload
	def moveTo(self, x: int, y: int) -> "Draw2DElement_Builder":
		pass

	pass





from typing import overload
from typing import TypeVar
from .RenderElement3D import RenderElement3D
from .Vec3D import Vec3D
from .BlockPosHelper import BlockPosHelper
from .Pos3D import Pos3D

net_minecraft_client_gui_DrawContext = TypeVar("net_minecraft_client_gui_DrawContext")
DrawContext = net_minecraft_client_gui_DrawContext

net_minecraft_client_render_BufferBuilder = TypeVar("net_minecraft_client_render_BufferBuilder")
BufferBuilder = net_minecraft_client_render_BufferBuilder


class Box(RenderElement3D):
	"""
	"""
	pos: Vec3D
	color: int
	fillColor: int
	fill: bool
	cull: bool

	@overload
	def __init__(self, x1: float, y1: float, z1: float, x2: float, y2: float, z2: float, color: int, fillColor: int, fill: bool, cull: bool) -> None:
		pass

	@overload
	def __init__(self, x1: float, y1: float, z1: float, x2: float, y2: float, z2: float, color: int, alpha: int, fillColor: int, fillAlpha: int, fill: bool, cull: bool) -> None:
		pass

	@overload
	def setPos(self, x1: float, y1: float, z1: float, x2: float, y2: float, z2: float) -> None:
		"""
		Since: 1.0.6 

		Args:
			z1: 
			y1: 
			z2: 
			x1: 
			y2: 
			x2: 
		"""
		pass

	@overload
	def setPosToBlock(self, pos: BlockPosHelper) -> None:
		"""set this component's pos to a block\n
		Since: 1.9.0 
		"""
		pass

	@overload
	def setPosToBlock(self, x: int, y: int, z: int) -> None:
		"""set this component's pos to a block\n
		Since: 1.9.0 
		"""
		pass

	@overload
	def setPosToPoint(self, pos: Pos3D, radius: float) -> None:
		"""set this component's pos to a point\n
		Since: 1.9.0 
		"""
		pass

	@overload
	def setPosToPoint(self, x: float, y: float, z: float, radius: float) -> None:
		"""set this component's pos to a point\n
		Since: 1.9.0 
		"""
		pass

	@overload
	def setColor(self, color: int) -> None:
		"""
		Since: 1.0.6 

		Args:
			color: 
		"""
		pass

	@overload
	def setFillColor(self, fillColor: int) -> None:
		"""
		Since: 1.0.6 

		Args:
			fillColor: 
		"""
		pass

	@overload
	def setColor(self, color: int, alpha: int) -> None:
		"""
		Since: 1.1.8 

		Args:
			color: 
			alpha: 
		"""
		pass

	@overload
	def setAlpha(self, alpha: int) -> None:
		"""
		Since: 1.1.8 

		Args:
			alpha: 
		"""
		pass

	@overload
	def setFillColor(self, fillColor: int, alpha: int) -> None:
		"""
		Since: 1.1.8 

		Args:
			fillColor: 
			alpha: 
		"""
		pass

	@overload
	def setFillAlpha(self, alpha: int) -> None:
		"""
		Since: 1.1.8 

		Args:
			alpha: 
		"""
		pass

	@overload
	def setFill(self, fill: bool) -> None:
		"""
		Since: 1.0.6 

		Args:
			fill: 
		"""
		pass

	@overload
	def equals(self, o: object) -> bool:
		pass

	@overload
	def hashCode(self) -> int:
		pass

	@overload
	def compareToSame(self, other: "Box") -> int:
		pass

	@overload
	def render(self, drawContext: DrawContext, builder: BufferBuilder, tickDelta: float) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Generic

T = TypeVar("T")
java_lang_Runnable = TypeVar("java_lang_Runnable")
Runnable = java_lang_Runnable

java_lang_Thread = TypeVar("java_lang_Thread")
Thread = java_lang_Thread


class EventContainer(Generic[T]):
	"""
	Since: 1.4.0 
	"""

	@overload
	def __init__(self, ctx: T) -> None:
		pass

	@overload
	def isLocked(self) -> bool:
		pass

	@overload
	def setLockThread(self, lockThread: Thread) -> None:
		pass

	@overload
	def getCtx(self) -> T:
		pass

	@overload
	def getLockThread(self) -> Thread:
		pass

	@overload
	def awaitLock(self, then: Runnable) -> None:
		"""careful with this one it can cause deadlocks if used in scripts incorrectly.\n
		Since: 1.4.0 

		Args:
			then: must be a MethodWrapper when called from a script. 
		"""
		pass

	@overload
	def releaseLock(self) -> None:
		"""can be released earlier in a script or language impl.\n
		Since: 1.4.0 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar
from .MobEntityHelper import MobEntityHelper

net_minecraft_entity_mob_WardenEntity = TypeVar("net_minecraft_entity_mob_WardenEntity")
WardenEntity = net_minecraft_entity_mob_WardenEntity


class WardenEntityHelper(MobEntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: WardenEntity) -> None:
		pass

	@overload
	def getAnger(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			this warden's anger towards its active target. 
		"""
		pass

	@overload
	def isDigging(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this warden is digging into the ground, 'false' otherwise. 
		"""
		pass

	@overload
	def isEmerging(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this warden is emerging from the ground, 'false' otherwise. 
		"""
		pass

	@overload
	def isRoaring(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this warden is roaring, 'false' otherwise. 
		"""
		pass

	@overload
	def isSniffing(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this warden is sniffing, 'false' otherwise. 
		"""
		pass

	@overload
	def isChargingSonicBoom(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this warden is charging its sonic boom attack, 'false' otherwise. 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar

java_io_File = TypeVar("java_io_File")
File = java_io_File

java_util_Comparator_java_io_File_ = TypeVar("java_util_Comparator_java_io_File_")
Comparator = java_util_Comparator_java_io_File_


class FileChooser_sortFile(Comparator):

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def compare(self, a: File, b: File) -> int:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from typing import Any
from .PerExecLibrary import PerExecLibrary
from .TickSync import TickSync
from .BaseScriptContext import BaseScriptContext
from .RegistryHelper import RegistryHelper
from .PacketByteBufferHelper import PacketByteBufferHelper
from .MethodWrapper import MethodWrapper
from .OptionsHelper import OptionsHelper
from .ServerInfoHelper import ServerInfoHelper
from .ModContainerHelper import ModContainerHelper
from .BlockHelper import BlockHelper
from .ItemHelper import ItemHelper

net_minecraft_network_packet_Packet_net_minecraft_network_listener_ClientPlayPacketListener_ = TypeVar("net_minecraft_network_packet_Packet_net_minecraft_network_listener_ClientPlayPacketListener_")
Packet = net_minecraft_network_packet_Packet_net_minecraft_network_listener_ClientPlayPacketListener_

net_minecraft_client_MinecraftClient = TypeVar("net_minecraft_client_MinecraftClient")
MinecraftClient = net_minecraft_client_MinecraftClient


class FClient(PerExecLibrary):
	"""Functions that interact with minecraft that don't fit into their own module. 
An instance of this class is passed to scripts as the 'Client' variable.\n
	Since: 1.2.9 
	"""
	tickSynchronizer: TickSync

	@overload
	def __init__(self, context: BaseScriptContext) -> None:
		pass

	@overload
	def getMinecraft(self) -> MinecraftClient:
		"""
		Since: 1.0.0 (was in the 'jsmacros' library until 1.2.9) 

		Returns:
			the raw minecraft client class, it may be useful to use Minecraft Mappings Viewer for this. 
		"""
		pass

	@overload
	def getRegistryManager(self) -> RegistryHelper:
		"""
		Since: 1.8.4 

		Returns:
			a helper for interacting with minecraft's registry. 
		"""
		pass

	@overload
	def createPacketByteBuffer(self) -> PacketByteBufferHelper:
		"""
		Since: 1.8.4 

		Returns:
			a helper to modify and send minecraft packets. 
		"""
		pass

	@overload
	def runOnMainThread(self, runnable: MethodWrapper) -> None:
		"""Run your task on the main minecraft thread\n
		Since: 1.4.0 

		Args:
			runnable: task to run 
		"""
		pass

	@overload
	def runOnMainThread(self, runnable: MethodWrapper, watchdogMaxTime: float) -> None:
		"""
		Since: 1.6.5 

		Args:
			runnable: 
			watchdogMaxTime: 
		"""
		pass

	@overload
	def runOnMainThread(self, runnable: MethodWrapper, await_: bool, watchdogMaxTime: float) -> None:
		"""
		Since: 1.9.1 

		Args:
			runnable: 
			watchdogMaxTime: max time for the watchdog to wait before killing the script 
			await: 
		"""
		pass

	@overload
	def getGameOptions(self) -> OptionsHelper:
		"""
		Since: 1.1.7 (was in the 'jsmacros' library until 1.2.9) 

		Returns:
			a helper which gives access to all game options and some other useful features. 
		"""
		pass

	@overload
	def mcVersion(self) -> str:
		"""
		Since: 1.1.2 (was in the 'jsmacros' library until 1.2.9) 

		Returns:
			the current minecraft version as a String . 
		"""
		pass

	@overload
	def getFPS(self) -> str:
		"""
		Since: 1.2.0 (was in the 'jsmacros' library until 1.2.9) 

		Returns:
			the fps debug string from minecraft. 
		"""
		pass

	@overload
	def loadWorld(self, folderName: str) -> None:
		"""Join singleplayer world\n
		Since: 1.6.6 

		Args:
			folderName: 
		"""
		pass

	@overload
	def connect(self, ip: str) -> None:
		"""
		Since: 1.2.3 (was in the 'jsmacros' library until 1.2.9) 

		Args:
			ip: 
		"""
		pass

	@overload
	def connect(self, ip: str, port: int) -> None:
		"""Connect to a server\n
		Since: 1.2.3 (was in the 'jsmacros' library until 1.2.9) 

		Args:
			port: 
			ip: 
		"""
		pass

	@overload
	def disconnect(self) -> None:
		"""
		Since: 1.2.3 (was in the 'jsmacros' library until 1.2.9) 
		"""
		pass

	@overload
	def disconnect(self, callback: MethodWrapper) -> None:
		"""Disconnect from a server with callback.\n
		Since: 1.2.3 (was in the 'jsmacros' library until 1.2.9) 
'callback' defaults to 'null' 

		Args:
			callback: calls your method as a Consumer Boolean 
		"""
		pass

	@overload
	def shutdown(self) -> None:
		"""Closes the client (stops the game).
Waits until the game has stopped, meaning no further code is executed (for obvious reasons).
Warning: this does not wait on joined threads, so your script may stop at an undefined point.\n
		Since: 1.6.0 
		"""
		pass

	@overload
	def waitTick(self) -> None:
		"""
		Since: 1.2.4 
		"""
		pass

	@overload
	def waitTick(self, i: int) -> None:
		"""waits the specified number of client ticks.
don't use this on an event that the main thread waits on (joins)... that'll cause circular waiting.\n
		Since: 1.2.6 

		Args:
			i: 
		"""
		pass

	@overload
	def ping(self, ip: str) -> ServerInfoHelper:
		"""
		Since: 1.6.5 

		Args:
			ip: 
		"""
		pass

	@overload
	def pingAsync(self, ip: str, callback: MethodWrapper) -> None:
		"""
		Since: 1.6.5 

		Args:
			ip: 
			callback: 
		"""
		pass

	@overload
	def cancelAllPings(self) -> None:
		"""
		Since: 1.6.5 
		"""
		pass

	@overload
	def getLoadedMods(self) -> List[Any]:
		"""
		Since: 1.8.4 

		Returns:
			a list of all loaded mods. 
		"""
		pass

	@overload
	def isModLoaded(self, modId: str) -> bool:
		"""
		Since: 1.8.4 

		Args:
			modId: the mod modId 

		Returns:
			'true' if the mod with the given modId is loaded, 'false' otherwise. 
		"""
		pass

	@overload
	def getMod(self, modId: str) -> ModContainerHelper:
		"""
		Since: 1.8.4 

		Args:
			modId: the mod modId 

		Returns:
			the mod container for the given modId or 'null' if the mod is not loaded. 
		"""
		pass

	@overload
	def grabMouse(self) -> None:
		"""Makes minecraft believe that the mouse is currently inside the window.
This will automatically set pause on lost focus to false.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def isDevEnv(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the mod is loaded inside a development environment, 'false' otherwise. 
		"""
		pass

	@overload
	def getModLoader(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the name of the mod loader. 
		"""
		pass

	@overload
	def getRegisteredBlocks(self) -> List[BlockHelper]:
		"""
		Since: 1.8.4 

		Returns:
			a list of all loaded blocks as BlockHelper objects. 
		"""
		pass

	@overload
	def getRegisteredItems(self) -> List[ItemHelper]:
		"""
		Since: 1.8.4 

		Returns:
			a list of all loaded items as ItemHelper objects. 
		"""
		pass

	@overload
	def exitGamePeacefully(self) -> None:
		"""Tries to peacefully close the game.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def exitGameForcefully(self) -> None:
		"""Will close the game forcefully.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def sendPacket(self, packet: Packet) -> None:
		"""
		Since: 1.8.4 

		Args:
			packet: the packet to send 
		"""
		pass

	@overload
	def receivePacket(self, packet: Packet) -> None:
		"""
		Since: 1.8.4 

		Args:
			packet: the packet to receive 
		"""
		pass

	pass





from typing import overload
from typing import List
from .BaseEvent import BaseEvent
from .BlockPosHelper import BlockPosHelper
from .ItemStackHelper import ItemStackHelper


class EventDeath(BaseEvent):
	"""
	Since: 1.2.7 
	"""
	deathPos: BlockPosHelper
	inventory: List[ItemStackHelper]

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def respawn(self) -> None:
		"""Respawns the player. Should be used with some delay, one tick should be enough.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .ItemStackHelper import ItemStackHelper
from .TextHelper import TextHelper
from .EnchantmentHelper import EnchantmentHelper

net_minecraft_item_ItemStack = TypeVar("net_minecraft_item_ItemStack")
ItemStack = net_minecraft_item_ItemStack


class CreativeItemStackHelper(ItemStackHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, itemStack: ItemStack) -> None:
		pass

	@overload
	def setDamage(self, damage: int) -> "CreativeItemStackHelper":
		"""
		Since: 1.8.4 

		Args:
			damage: the damage the item should take 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def setDurability(self, durability: int) -> "CreativeItemStackHelper":
		"""
		Since: 1.8.4 

		Args:
			durability: the new durability of this item 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def setCount(self, count: int) -> "CreativeItemStackHelper":
		"""
		Since: 1.8.4 

		Args:
			count: the new count of the item 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def setName(self, name: str) -> "CreativeItemStackHelper":
		"""
		Since: 1.8.4 

		Args:
			name: the new name of the item 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def setName(self, name: TextHelper) -> "CreativeItemStackHelper":
		"""
		Since: 1.8.4 

		Args:
			name: the new name of the item 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def addEnchantment(self, id: str, level: int) -> "CreativeItemStackHelper":
		"""
		Since: 1.8.4 

		Args:
			level: the level of the enchantment 
			id: the id of the enchantment 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def addEnchantment(self, enchantment: EnchantmentHelper) -> "CreativeItemStackHelper":
		"""
		Since: 1.8.4 

		Args:
			enchantment: the enchantment to add 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def clearEnchantments(self) -> "CreativeItemStackHelper":
		"""
		Since: 1.8.4 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def removeEnchantment(self, enchantment: EnchantmentHelper) -> "CreativeItemStackHelper":
		"""
		Since: 1.8.4 

		Args:
			enchantment: the enchantment to remove 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def removeEnchantment(self, id: str) -> "CreativeItemStackHelper":
		"""
		Since: 1.8.4 

		Args:
			id: the id of the enchantment to remove 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def clearLore(self) -> "CreativeItemStackHelper":
		"""
		Since: 1.8.4 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def setLore(self, lore: List[object]) -> "CreativeItemStackHelper":
		"""
		Since: 1.8.4 

		Args:
			lore: the new lore 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def addLore(self, lore: List[object]) -> "CreativeItemStackHelper":
		"""
		Since: 1.8.4 

		Args:
			lore: the lore to add 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def setUnbreakable(self, unbreakable: bool) -> "CreativeItemStackHelper":
		"""
		Since: 1.8.4 

		Args:
			unbreakable: whether the item should be unbreakable or not 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def hideEnchantments(self, hide: bool) -> "CreativeItemStackHelper":
		"""
		Since: 1.8.4 

		Args:
			hide: whether to hide the enchantments or not 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def hideModifiers(self, hide: bool) -> "CreativeItemStackHelper":
		"""
		Since: 1.8.4 

		Args:
			hide: whether to hide attributes and modifiers or not 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def hideUnbreakable(self, hide: bool) -> "CreativeItemStackHelper":
		"""
		Since: 1.8.4 

		Args:
			hide: whether to hide the unbreakable flag or not 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def hideCanDestroy(self, hide: bool) -> "CreativeItemStackHelper":
		"""
		Since: 1.8.4 

		Args:
			hide: whether to hide the blocks this item can destroy or not 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def hideCanPlace(self, hide: bool) -> "CreativeItemStackHelper":
		"""
		Since: 1.8.4 

		Args:
			hide: whether to hide the blocks this item can be placed on or not 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def hideDye(self, hide: bool) -> "CreativeItemStackHelper":
		"""
		Since: 1.8.4 

		Args:
			hide: whether to hide the color of colored leather armor or not 

		Returns:
			self for chaining. 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from .RenderElement3D import RenderElement3D
from .Vec3D import Vec3D

net_minecraft_client_gui_DrawContext = TypeVar("net_minecraft_client_gui_DrawContext")
DrawContext = net_minecraft_client_gui_DrawContext

net_minecraft_client_render_BufferBuilder = TypeVar("net_minecraft_client_render_BufferBuilder")
BufferBuilder = net_minecraft_client_render_BufferBuilder


class Line3D(RenderElement3D):
	"""
	"""
	pos: Vec3D
	color: int
	cull: bool

	@overload
	def __init__(self, x1: float, y1: float, z1: float, x2: float, y2: float, z2: float, color: int, cull: bool) -> None:
		pass

	@overload
	def __init__(self, x1: float, y1: float, z1: float, x2: float, y2: float, z2: float, color: int, alpha: int, cull: bool) -> None:
		pass

	@overload
	def setPos(self, x1: float, y1: float, z1: float, x2: float, y2: float, z2: float) -> None:
		"""
		Since: 1.0.6 

		Args:
			z1: 
			y1: 
			z2: 
			x1: 
			y2: 
			x2: 
		"""
		pass

	@overload
	def setColor(self, color: int) -> None:
		"""
		Since: 1.0.6 

		Args:
			color: 
		"""
		pass

	@overload
	def setColor(self, color: int, alpha: int) -> None:
		"""
		Since: 1.1.8 

		Args:
			color: 
			alpha: 
		"""
		pass

	@overload
	def setAlpha(self, alpha: int) -> None:
		"""
		Since: 1.1.8 

		Args:
			alpha: 
		"""
		pass

	@overload
	def equals(self, o: object) -> bool:
		pass

	@overload
	def hashCode(self) -> int:
		pass

	@overload
	def compareToSame(self, o: "Line3D") -> int:
		pass

	@overload
	def render(self, drawContext: DrawContext, builder: BufferBuilder, tickDelta: float) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar
from .ScriptTrigger import ScriptTrigger

java_util_Comparator_xyz_wagyourtail_jsmacros_core_config_ScriptTrigger_ = TypeVar("java_util_Comparator_xyz_wagyourtail_jsmacros_core_config_ScriptTrigger_")
Comparator = java_util_Comparator_xyz_wagyourtail_jsmacros_core_config_ScriptTrigger_


class Sorting_SortByFileName(Comparator):

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def compare(self, a: ScriptTrigger, b: ScriptTrigger) -> int:
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Generic
from .MobEntityHelper import MobEntityHelper
from .ItemHelper import ItemHelper
from .ItemStackHelper import ItemStackHelper

T = TypeVar("T")

class AnimalEntityHelper(Generic[T], MobEntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: T) -> None:
		pass

	@overload
	def isFood(self, item: ItemHelper) -> bool:
		"""
		Since: 1.8.4 

		Args:
			item: the item to check 

		Returns:
			'true' if the item can be used to feed and breed this animal, 'false' otherwise. 
		"""
		pass

	@overload
	def isFood(self, item: ItemStackHelper) -> bool:
		"""
		Since: 1.8.4 

		Args:
			item: the item to check 

		Returns:
			'true' if the item can be used to feed and breed this animal, 'false' otherwise. 
		"""
		pass

	@overload
	def canBreedWith(self, other: "AnimalEntityHelper") -> bool:
		"""
		Since: 1.8.4 

		Args:
			other: the other animal to check 

		Returns:
			'true' if this animal can be bred with the other animal, 'false' otherwise. 
		"""
		pass

	pass





from typing import overload
from typing import List
from .Inventory import Inventory
from .ItemStackHelper import ItemStackHelper
from .TextHelper import TextHelper


class CreativeInventory(Inventory):
	"""
	Since: 1.8.4 
	"""

	@overload
	def scroll(self, amount: float) -> "CreativeInventory":
		"""The total scroll value is always clamp between 0 and 1.\n
		Since: 1.8.4 

		Args:
			amount: the amount to scroll by, between -1 and 1 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def scrollTo(self, position: float) -> "CreativeInventory":
		"""The total scroll value is always clamp between 0 and 1.\n
		Since: 1.8.4 

		Args:
			position: the position to scroll to, between 0 and 1 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getShownItems(self) -> List[ItemStackHelper]:
		"""
		Since: 1.8.4 

		Returns:
			a list of all shown items. 
		"""
		pass

	@overload
	def search(self, search: str) -> "CreativeInventory":
		"""
		Since: 1.8.4 

		Args:
			search: the string to search for 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def selectSearch(self) -> "CreativeInventory":
		"""Select the search tab.\n
		Since: 1.8.4 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def selectInventory(self) -> "CreativeInventory":
		"""Select the inventory tab.\n
		Since: 1.8.4 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def selectHotbar(self) -> "CreativeInventory":
		"""Select the tab where the hotbars are stored.\n
		Since: 1.8.4 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def selectTab(self, tabName: str) -> "CreativeInventory":
		"""
		Since: 1.8.4 

		Args:
			tabName: the name of the tab to select 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getTabNames(self) -> List[str]:
		pass

	@overload
	def getTabTexts(self) -> List[TextHelper]:
		pass

	@overload
	def destroyHeldItem(self) -> "CreativeInventory":
		"""Destroys the currently held item.\n
		Since: 1.8.4 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def destroyAllItems(self) -> "CreativeInventory":
		"""Destroys all items in the player's inventory.\n
		Since: 1.8.4 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def setCursorStack(self, stack: ItemStackHelper) -> "CreativeInventory":
		"""
		Since: 1.8.4 

		Args:
			stack: the item stack to drag 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def setStack(self, slot: int, stack: ItemStackHelper) -> "CreativeInventory":
		"""
		Since: 1.8.4 

		Args:
			stack: the item stack to insert 
			slot: the slot to insert the item into 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def saveHotbar(self, index: int) -> "CreativeInventory":
		"""
		Since: 1.8.4 

		Args:
			index: the index to save the hotbar to, from 0 to 8 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def restoreHotbar(self, index: int) -> "CreativeInventory":
		"""
		Since: 1.8.4 

		Args:
			index: the index to save the hotbar to, from 0 to 8 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getSavedHotbar(self, index: int) -> List[ItemStackHelper]:
		"""
		Since: 1.8.4 

		Args:
			index: the index to save the hotbar to, from 0 to 8 

		Returns:
			a list of all items in the saved hotbar. 
		"""
		pass

	@overload
	def isInHotbar(self, slot: int) -> bool:
		"""
		Since: 1.8.4 

		Args:
			slot: the slot to check 

		Returns:
			'true' if the slot is in the hotbar or the offhand slot, 'false' otherwise. 
		"""
		pass

	@overload
	def getOffhand(self) -> ItemStackHelper:
		"""
		Since: 1.8.4 

		Returns:
			the item in the offhand. 
		"""
		pass

	@overload
	def getHelmet(self) -> ItemStackHelper:
		"""
		Since: 1.8.4 

		Returns:
			the equipped helmet item. 
		"""
		pass

	@overload
	def getChestplate(self) -> ItemStackHelper:
		"""
		Since: 1.8.4 

		Returns:
			the equipped chestplate item. 
		"""
		pass

	@overload
	def getLeggings(self) -> ItemStackHelper:
		"""
		Since: 1.8.4 

		Returns:
			the equipped leggings item. 
		"""
		pass

	@overload
	def getBoots(self) -> ItemStackHelper:
		"""
		Since: 1.8.4 

		Returns:
			the equipped boots item. 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar

net_minecraft_client_font_FontManager = TypeVar("net_minecraft_client_font_FontManager")
FontManager = net_minecraft_client_font_FontManager


class IMinecraftClient:

	@overload
	def jsmacros_getFontManager(self) -> FontManager:
		pass

	@overload
	def jsmacros_doItemUse(self) -> None:
		pass

	@overload
	def jsmacros_doAttack(self) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar

net_minecraft_text_ClickEvent = TypeVar("net_minecraft_text_ClickEvent")
ClickEvent = net_minecraft_text_ClickEvent

java_lang_Runnable = TypeVar("java_lang_Runnable")
Runnable = java_lang_Runnable


class CustomClickEvent(ClickEvent):

	@overload
	def __init__(self, event: Runnable) -> None:
		pass

	@overload
	def hashCode(self) -> int:
		pass

	@overload
	def getEvent(self) -> Runnable:
		pass

	pass





from typing import overload
from typing import TypeVar
from .BaseEvent import BaseEvent
from .IScreen import IScreen

net_minecraft_client_gui_screen_Screen = TypeVar("net_minecraft_client_gui_screen_Screen")
Screen = net_minecraft_client_gui_screen_Screen


class EventOpenScreen(BaseEvent):
	"""
	Since: 1.2.7 
	"""
	screen: IScreen
	screenName: str

	@overload
	def __init__(self, screen: Screen) -> None:
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .BaseScreen import BaseScreen
from .History import History
from .SelectCursor import SelectCursor
from .AbstractRenderCodeCompiler import AbstractRenderCodeCompiler

net_minecraft_client_gui_screen_Screen = TypeVar("net_minecraft_client_gui_screen_Screen")
Screen = net_minecraft_client_gui_screen_Screen

net_minecraft_client_gui_DrawContext = TypeVar("net_minecraft_client_gui_DrawContext")
DrawContext = net_minecraft_client_gui_DrawContext

net_minecraft_text_Style = TypeVar("net_minecraft_text_Style")
Style = net_minecraft_text_Style

java_io_File = TypeVar("java_io_File")
File = java_io_File


class EditorScreen(BaseScreen):
	langs: List[str]
	defaultStyle: Style
	history: History
	cursor: SelectCursor
	blockFirst: bool
	textRenderTime: float
	prevChar: str
	language: str
	codeCompiler: AbstractRenderCodeCompiler

	@overload
	def __init__(self, parent: Screen, file: File) -> None:
		pass

	@overload
	def getDefaultLanguage(self) -> str:
		pass

	@overload
	def openAndScrollToIndex(self, file: File, startIndex: int, endIndex: int) -> None:
		pass

	@overload
	def openAndScrollToLine(self, file: File, line: int, col: int, endCol: int) -> None:
		pass

	@overload
	def setScroll(self, pages: float) -> None:
		pass

	@overload
	def setLanguage(self, language: str) -> None:
		pass

	@overload
	def init(self) -> None:
		pass

	@overload
	def copyToClipboard(self) -> None:
		pass

	@overload
	def pasteFromClipboard(self) -> None:
		pass

	@overload
	def cutToClipboard(self) -> None:
		pass

	@overload
	def keyPressed(self, keyCode: int, scanCode: int, modifiers: int) -> bool:
		pass

	@overload
	def scrollToCursor(self) -> None:
		pass

	@overload
	def save(self) -> None:
		pass

	@overload
	def needSave(self) -> bool:
		pass

	@overload
	def mouseScrolled(self, mouseX: float, mouseY: float, horiz: float, vert: float) -> bool:
		pass

	@overload
	def render(self, drawContext: DrawContext, mouseX: int, mouseY: int, delta: float) -> None:
		pass

	@overload
	def openParent(self) -> None:
		pass

	@overload
	def mouseClicked(self, mouseX: float, mouseY: float, btn: int) -> bool:
		pass

	@overload
	def selectWordAtCursor(self) -> None:
		pass

	@overload
	def mouseDragged(self, mouseX: float, mouseY: float, button: int, deltaX: float, deltaY: float) -> bool:
		pass

	@overload
	def updateSettings(self) -> None:
		pass

	@overload
	def charTyped(self, chr: str, keyCode: int) -> bool:
		pass

	pass





from typing import overload
from typing import TypeVar
from .BaseEvent import BaseEvent
from .Inventory import Inventory
from .IScreen import IScreen

net_minecraft_client_gui_screen_ingame_HandledScreen__ = TypeVar("net_minecraft_client_gui_screen_ingame_HandledScreen__")
HandledScreen = net_minecraft_client_gui_screen_ingame_HandledScreen__


class EventOpenContainer(BaseEvent):
	"""
	Since: 1.6.5 
	"""
	inventory: Inventory
	screen: IScreen

	@overload
	def __init__(self, screen: HandledScreen) -> None:
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar
from .BaseEvent import BaseEvent
from .PlayerListEntryHelper import PlayerListEntryHelper

net_minecraft_client_network_PlayerListEntry = TypeVar("net_minecraft_client_network_PlayerListEntry")
PlayerListEntry = net_minecraft_client_network_PlayerListEntry

java_util_UUID = TypeVar("java_util_UUID")
UUID = java_util_UUID


class EventPlayerLeave(BaseEvent):
	"""
	Since: 1.2.7 
	"""
	UUID: str
	player: PlayerListEntryHelper

	@overload
	def __init__(self, uuid: UUID, player: PlayerListEntry) -> None:
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar
from .AbstractHorseEntityHelper import AbstractHorseEntityHelper

net_minecraft_entity_passive_HorseEntity = TypeVar("net_minecraft_entity_passive_HorseEntity")
HorseEntity = net_minecraft_entity_passive_HorseEntity


class HorseEntityHelper(AbstractHorseEntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: HorseEntity) -> None:
		pass

	@overload
	def getVariant(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the variant of this horse. 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from .AnimalEntityHelper import AnimalEntityHelper

net_minecraft_entity_passive_MooshroomEntity = TypeVar("net_minecraft_entity_passive_MooshroomEntity")
MooshroomEntity = net_minecraft_entity_passive_MooshroomEntity


class MooshroomEntityHelper(AnimalEntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: MooshroomEntity) -> None:
		pass

	@overload
	def isShearable(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this mooshroom can be sheared, 'false' otherwise. 
		"""
		pass

	@overload
	def isRed(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this mooshroom is a red mooshroom, 'false' otherwise. 
		"""
		pass

	@overload
	def isBrown(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this mooshroom is a brown mooshroom, 'false' otherwise. 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from .ZombieEntityHelper import ZombieEntityHelper

net_minecraft_entity_mob_ZombieVillagerEntity = TypeVar("net_minecraft_entity_mob_ZombieVillagerEntity")
ZombieVillagerEntity = net_minecraft_entity_mob_ZombieVillagerEntity


class ZombieVillagerEntityHelper(ZombieEntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: ZombieVillagerEntity) -> None:
		pass

	@overload
	def isConvertingToVillager(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this zombie villager is currently being converted back to a villager, 'false' otherwise. 
		"""
		pass

	@overload
	def getVillagerBiomeType(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the type of biome the villager belonged to it was converted to a zombie. 
		"""
		pass

	@overload
	def getProfession(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the profession of the villager before it was converted to a zombie. 
		"""
		pass

	@overload
	def getLevel(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the level of the villager before it was converted to a zombie. 
		"""
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from typing import Mapping
from .AbstractRenderCodeCompiler import AbstractRenderCodeCompiler
from .EditorScreen import EditorScreen
from .AutoCompleteSuggestion import AutoCompleteSuggestion

java_lang_Runnable = TypeVar("java_lang_Runnable")
Runnable = java_lang_Runnable

net_minecraft_text_Text = TypeVar("net_minecraft_text_Text")
Text = net_minecraft_text_Text


class NoStyleCodeCompiler(AbstractRenderCodeCompiler):

	@overload
	def __init__(self, language: str, screen: EditorScreen) -> None:
		pass

	@overload
	def recompileRenderedText(self, text: str) -> None:
		pass

	@overload
	def getRightClickOptions(self, index: int) -> Mapping[str, Runnable]:
		pass

	@overload
	def getRenderedText(self) -> List[Text]:
		pass

	@overload
	def getSuggestions(self) -> List[AutoCompleteSuggestion]:
		pass

	pass





from typing import overload
from typing import TypeVar

net_minecraft_util_hit_HitResult = TypeVar("net_minecraft_util_hit_HitResult")
HitResult = net_minecraft_util_hit_HitResult

org_spongepowered_asm_mixin_injection_callback_CallbackInfo = TypeVar("org_spongepowered_asm_mixin_injection_callback_CallbackInfo")
CallbackInfo = org_spongepowered_asm_mixin_injection_callback_CallbackInfo

net_minecraft_util_math_BlockPos = TypeVar("net_minecraft_util_math_BlockPos")
BlockPos = net_minecraft_util_math_BlockPos


class InteractionProxy_Target:
	checkDistance: bool
	clearIfOutOfRange: bool
	checkAir: bool
	clearIfIsAir: bool
	checkShape: bool
	clearIfEmptyShape: bool

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def resetChecks(self) -> None:
		pass

	@overload
	def setTargetBlock(self, pos: BlockPos, direction: int) -> None:
		pass

	@overload
	def setTarget(self, value: HitResult) -> None:
		pass

	@overload
	def setTargetMissed(self) -> None:
		pass

	@overload
	def hasOverride(self) -> bool:
		pass

	@overload
	def onUpdate(self, tickDelta: float, ci: CallbackInfo) -> None:
		pass

	@overload
	def isInRange(self, tickDelta: float) -> bool:
		pass

	pass





from typing import overload
from typing import TypeVar
from .ClickableWidgetHelper import ClickableWidgetHelper

net_minecraft_client_gui_widget_CheckboxWidget = TypeVar("net_minecraft_client_gui_widget_CheckboxWidget")
CheckboxWidget = net_minecraft_client_gui_widget_CheckboxWidget


class CheckBoxWidgetHelper(ClickableWidgetHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, btn: CheckboxWidget) -> None:
		pass

	@overload
	def __init__(self, btn: CheckboxWidget, zIndex: int) -> None:
		pass

	@overload
	def isChecked(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this button is checked, 'false' otherwise. 
		"""
		pass

	@overload
	def toggle(self) -> "CheckBoxWidgetHelper":
		"""
		Since: 1.8.4 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def setChecked(self, checked: bool) -> "CheckBoxWidgetHelper":
		"""
		Since: 1.8.4 

		Args:
			checked: whether to check or uncheck this button 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .BaseLibrary import BaseLibrary

T = TypeVar("T")
java_util_HashMap_,_ = TypeVar("java_util_HashMap_,_")
HashMap = java_util_HashMap_,_

java_util_ArrayList_T_ = TypeVar("java_util_ArrayList_T_")
ArrayList = java_util_ArrayList_T_

java_util_SplittableRandom = TypeVar("java_util_SplittableRandom")
SplittableRandom = java_util_SplittableRandom

java_util_HashSet__ = TypeVar("java_util_HashSet__")
HashSet = java_util_HashSet__


class FJavaUtils(BaseLibrary):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def createArrayList(self) -> ArrayList:
		"""Creates a java ArrayList .\n
		Since: 1.8.4 

		Returns:
			a java ArrayList. 
		"""
		pass

	@overload
	def createArrayList(self, array: List[T]) -> ArrayList:
		"""Creates a java ArrayList .\n
		Since: 1.8.4 

		Args:
			T: the type of the array 
			array: the array to add to the list 

		Returns:
			a java ArrayList from the given array. 
		"""
		pass

	@overload
	def createHashMap(self) -> HashMap:
		"""Creates a java HashMap .\n
		Since: 1.8.4 

		Returns:
			a java HashMap. 
		"""
		pass

	@overload
	def createHashSet(self) -> HashSet:
		"""Creates a java HashSet .\n
		Since: 1.8.4 

		Returns:
			a java HashSet. 
		"""
		pass

	@overload
	def getRandom(self) -> SplittableRandom:
		"""Returns a SplittableRandom .\n
		Since: 1.8.4 

		Returns:
			a SplittableRandom. 
		"""
		pass

	@overload
	def getRandom(self, seed: float) -> SplittableRandom:
		"""Returns SplittableRandom , initialized with the seed to get identical sequences of
values at all times.\n
		Since: 1.8.4 

		Args:
			seed: the seed 

		Returns:
			a SplittableRandom. 
		"""
		pass

	@overload
	def getHelperFromRaw(self, raw: object) -> object:
		"""
		Since: 1.8.4 

		Args:
			raw: the object to wrap 

		Returns:
			the correct instance of BaseHelper for the given object if it exists and 'null' otherwise. 
		"""
		pass

	@overload
	def arrayToString(self, array: List[object]) -> str:
		"""
		Since: 1.8.4 

		Args:
			array: the array to convert 

		Returns:
			the String representation of the given array. 
		"""
		pass

	@overload
	def arrayDeepToString(self, array: List[object]) -> str:
		"""This method will convert any objects hold in the array data to Strings and should be used for
multidimensional arrays.\n
		Since: 1.8.4 

		Args:
			array: the array to convert 

		Returns:
			the String representation of the given array. 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from .ClickableWidgetHelper import ClickableWidgetHelper

net_minecraft_client_gui_widget_LockButtonWidget = TypeVar("net_minecraft_client_gui_widget_LockButtonWidget")
LockButtonWidget = net_minecraft_client_gui_widget_LockButtonWidget


class LockButtonWidgetHelper(ClickableWidgetHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, btn: LockButtonWidget) -> None:
		pass

	@overload
	def __init__(self, btn: LockButtonWidget, zIndex: int) -> None:
		pass

	@overload
	def isLocked(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the button is locked, 'false' otherwise. 
		"""
		pass

	@overload
	def setLocked(self, locked: bool) -> "LockButtonWidgetHelper":
		"""
		Since: 1.8.4 

		Args:
			locked: whether to lock the button or not 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar

net_minecraft_entity_Entity = TypeVar("net_minecraft_entity_Entity")
Entity = net_minecraft_entity_Entity

org_spongepowered_asm_mixin_injection_callback_CallbackInfoReturnable_net_minecraft_util_ActionResult_ = TypeVar("org_spongepowered_asm_mixin_injection_callback_CallbackInfoReturnable_net_minecraft_util_ActionResult_")
CallbackInfoReturnable = org_spongepowered_asm_mixin_injection_callback_CallbackInfoReturnable_net_minecraft_util_ActionResult_

org_spongepowered_asm_mixin_injection_callback_CallbackInfo = TypeVar("org_spongepowered_asm_mixin_injection_callback_CallbackInfo")
CallbackInfo = org_spongepowered_asm_mixin_injection_callback_CallbackInfo

net_minecraft_util_math_BlockPos = TypeVar("net_minecraft_util_math_BlockPos")
BlockPos = net_minecraft_util_math_BlockPos

net_minecraft_client_network_ClientPlayerEntity = TypeVar("net_minecraft_client_network_ClientPlayerEntity")
ClientPlayerEntity = net_minecraft_client_network_ClientPlayerEntity

net_minecraft_util_hit_BlockHitResult = TypeVar("net_minecraft_util_hit_BlockHitResult")
BlockHitResult = net_minecraft_util_hit_BlockHitResult

net_minecraft_util_Hand = TypeVar("net_minecraft_util_Hand")
Hand = net_minecraft_util_Hand

net_minecraft_util_math_Direction = TypeVar("net_minecraft_util_math_Direction")
Direction = net_minecraft_util_math_Direction

net_minecraft_entity_player_PlayerEntity = TypeVar("net_minecraft_entity_player_PlayerEntity")
PlayerEntity = net_minecraft_entity_player_PlayerEntity


class MixinClientPlayerInteractionManager:

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def onInteractBlock(self, player: ClientPlayerEntity, hand: Hand, hitResult: BlockHitResult, cir: CallbackInfoReturnable) -> None:
		pass

	@overload
	def onAttackBlock(self, pos: BlockPos, direction: Direction, cir: CallbackInfoReturnable) -> None:
		pass

	@overload
	def onAttackEntity(self, player: PlayerEntity, target: Entity, ci: CallbackInfo) -> None:
		pass

	@overload
	def onInteractEntity(self, player: PlayerEntity, entity: Entity, hand: Hand, cir: CallbackInfoReturnable) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar
from .TameableEntityHelper import TameableEntityHelper

net_minecraft_entity_passive_ParrotEntity = TypeVar("net_minecraft_entity_passive_ParrotEntity")
ParrotEntity = net_minecraft_entity_passive_ParrotEntity


class ParrotEntityHelper(TameableEntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: ParrotEntity) -> None:
		pass

	@overload
	def getVariant(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the variant of this parrot. 
		"""
		pass

	@overload
	def isSitting(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this parrot is sitting, 'false' otherwise. 
		"""
		pass

	@overload
	def isFlying(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this parrot is flying, 'false' otherwise. 
		"""
		pass

	@overload
	def isPartying(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this parrot is dancing to music, 'false' otherwise. 
		"""
		pass

	@overload
	def isStanding(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this parrot is just standing around, 'false' otherwise. 
		"""
		pass

	@overload
	def isSittingOnShoulder(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this parrot is sitting on any player's shoulder, 'false' otherwise. 
		"""
		pass

	pass





from typing import overload
from typing import List


class NameUtil:
	"""
	Since: 1.8.4 
	"""

	@overload
	def guessNameAndRoles(self, text: str) -> List[str]:
		"""An approach to retrieve the name of a player from a chat message. 
Iterate until . If found, get the next valid name 
Iterate until :. If found, get the last valid name 
Iterate until >>. If found get the last valid name 
Iterate until ->. If found get the last valid name (continue if empty) 
The potential last name is the last value between [] or before >. It's used when the
sentence just continues. 
There are some edge cases like "name > ", because it could also be "Guild >
name :". Since the last one is much more common, I will stay with this approach.

		Returns:
			a list of the name at index 0 and any potential roles as subsequent elements or an
empty list if the name could not be identified. 
		"""
		pass

	pass





from typing import overload
from .Draw3D import Draw3D
from .Pos3D import Pos3D
from .BlockPosHelper import BlockPosHelper
from .Line3D import Line3D


class Line3D_Builder:
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, parent: Draw3D) -> None:
		pass

	@overload
	def pos1(self, pos1: Pos3D) -> "Line3D_Builder":
		"""
		Since: 1.8.4 

		Args:
			pos1: the first position of the line 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def pos1(self, pos1: BlockPosHelper) -> "Line3D_Builder":
		"""
		Since: 1.8.4 

		Args:
			pos1: the first position of the line 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def pos1(self, x1: float, y1: float, z1: float) -> "Line3D_Builder":
		"""
		Since: 1.8.4 

		Args:
			z1: the z coordinate of the first position of the line 
			y1: the y coordinate of the first position of the line 
			x1: the x coordinate of the first position of the line 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getPos1(self) -> Pos3D:
		"""
		Since: 1.8.4 

		Returns:
			the first position of the line. 
		"""
		pass

	@overload
	def pos2(self, pos2: Pos3D) -> "Line3D_Builder":
		"""
		Since: 1.8.4 

		Args:
			pos2: the second position of the line 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def pos2(self, pos2: BlockPosHelper) -> "Line3D_Builder":
		"""
		Since: 1.8.4 

		Args:
			pos2: the second position of the line 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def pos2(self, x2: int, y2: int, z2: int) -> "Line3D_Builder":
		"""
		Since: 1.8.4 

		Args:
			z2: the z coordinate of the second position of the line 
			y2: the y coordinate of the second position of the line 
			x2: the x coordinate of the second position of the line 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getPos2(self) -> Pos3D:
		"""
		Since: 1.8.4 

		Returns:
			the second position of the line. 
		"""
		pass

	@overload
	def pos(self, x1: int, y1: int, z1: int, x2: int, y2: int, z2: int) -> "Line3D_Builder":
		"""
		Since: 1.8.4 

		Args:
			z1: the z coordinate of the first position of the line 
			y1: the y coordinate of the first position of the line 
			z2: the z coordinate of the second position of the line 
			x1: the x coordinate of the first position of the line 
			y2: the x coordinate of the second position of the line 
			x2: the x coordinate of the second position of the line 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def pos(self, pos1: BlockPosHelper, pos2: BlockPosHelper) -> "Line3D_Builder":
		"""
		Since: 1.8.4 

		Args:
			pos1: the first position of the line 
			pos2: the second position of the line 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def pos(self, pos1: Pos3D, pos2: Pos3D) -> "Line3D_Builder":
		"""
		Since: 1.8.4 

		Args:
			pos1: the first position of the line 
			pos2: the second position of the line 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def color(self, color: int) -> "Line3D_Builder":
		"""
		Since: 1.8.4 

		Args:
			color: the color of the line 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def color(self, color: int, alpha: int) -> "Line3D_Builder":
		"""
		Since: 1.8.4 

		Args:
			color: the color of the line 
			alpha: the alpha value of the line's color 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def color(self, r: int, g: int, b: int) -> "Line3D_Builder":
		"""
		Since: 1.8.4 

		Args:
			r: the red component of the color 
			b: the blue component of the color 
			g: the green component of the color 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def color(self, r: int, g: int, b: int, a: int) -> "Line3D_Builder":
		"""
		Since: 1.8.4 

		Args:
			a: the alpha value of the color 
			r: the red component of the color 
			b: the blue component of the color 
			g: the green component of the color 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getColor(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the color of the line. 
		"""
		pass

	@overload
	def alpha(self, alpha: int) -> "Line3D_Builder":
		"""
		Since: 1.8.4 

		Args:
			alpha: the alpha value for the line's color 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getAlpha(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the alpha value of the line's color. 
		"""
		pass

	@overload
	def cull(self, cull: bool) -> "Line3D_Builder":
		"""
		Since: 1.8.4 

		Args:
			cull: whether to cull the line or not 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def isCulled(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the line should be culled, 'false' otherwise. 
		"""
		pass

	@overload
	def buildAndAdd(self) -> Line3D:
		"""Creates the line for the given values and adds it to the draw3D.\n
		Since: 1.8.4 

		Returns:
			the build line. 
		"""
		pass

	@overload
	def build(self) -> Line3D:
		"""Builds the line from the given values.

		Returns:
			the build line. 
		"""
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .BaseHelper import BaseHelper
from .BlockHelper import BlockHelper
from .StatePredicateHelper import StatePredicateHelper
from .NbtPredicateHelper import NbtPredicateHelper
from .BlockPosHelper import BlockPosHelper

net_minecraft_predicate_BlockPredicate = TypeVar("net_minecraft_predicate_BlockPredicate")
BlockPredicate = net_minecraft_predicate_BlockPredicate


class BlockPredicateHelper(BaseHelper):
	"""
	Since: 1.9.1 
	"""

	@overload
	def __init__(self, base: BlockPredicate) -> None:
		pass

	@overload
	def getBlocks(self) -> List[BlockHelper]:
		"""
		Since: 1.9.1 
		"""
		pass

	@overload
	def getStatePredicate(self) -> StatePredicateHelper:
		"""
		Since: 1.9.1 
		"""
		pass

	@overload
	def getNbtPredicate(self) -> NbtPredicateHelper:
		"""
		Since: 1.9.1 
		"""
		pass

	@overload
	def test(self, state: BlockPosHelper) -> bool:
		"""
		Since: 1.9.1 

		Args:
			state: 
		"""
		pass

	pass





from typing import overload
from typing import List


class Library:
	"""Base Function interface.
	"""

	@overload
	def value(self) -> str:
		pass

	@overload
	def languages(self) -> List[Class]:
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Generic
from .MultiElementContainer import MultiElementContainer
from .AbstractSettingContainer import AbstractSettingContainer
from .SettingsOverlay_SettingField import SettingsOverlay_SettingField

T = TypeVar("T")
net_minecraft_client_font_TextRenderer = TypeVar("net_minecraft_client_font_TextRenderer")
TextRenderer = net_minecraft_client_font_TextRenderer


class AbstractSettingField(Generic[T], MultiElementContainer):

	@overload
	def __init__(self, x: int, y: int, width: int, height: int, textRenderer: TextRenderer, parent: AbstractSettingContainer, field: SettingsOverlay_SettingField) -> None:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from typing import Generic
from .AbstractWidgetBuilder import AbstractWidgetBuilder
from .IScreen import IScreen
from .MethodWrapper import MethodWrapper
from .TextHelper import TextHelper
from .CyclingButtonWidgetHelper import CyclingButtonWidgetHelper

T = TypeVar("T")

class CyclingButtonWidgetHelper_CyclicButtonBuilder(Generic[T], AbstractWidgetBuilder):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, screen: IScreen, valueToText: MethodWrapper) -> None:
		pass

	@overload
	def getInitialValue(self) -> T:
		"""
		Since: 1.8.4 

		Returns:
			the initial value of the slider. 
		"""
		pass

	@overload
	def initially(self, value: T) -> "CyclingButtonWidgetHelper_CyclicButtonBuilder":
		"""
		Since: 1.8.4 

		Args:
			value: the initial value of the slider 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getOption(self) -> TextHelper:
		"""The option text is a prefix of all values, separated by a colon.\n
		Since: 1.8.4 

		Returns:
			the option text of the button or an empty text if it is omitted. 
		"""
		pass

	@overload
	def option(self, option: str) -> "CyclingButtonWidgetHelper_CyclicButtonBuilder":
		"""
		Since: 1.8.4 

		Args:
			option: the option text of the button 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def option(self, option: TextHelper) -> "CyclingButtonWidgetHelper_CyclicButtonBuilder":
		"""
		Since: 1.8.4 

		Args:
			option: the option text of the button 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getAction(self) -> MethodWrapper:
		"""
		Since: 1.8.4 

		Returns:
			the action to run when the button is pressed. 
		"""
		pass

	@overload
	def action(self, action: MethodWrapper) -> "CyclingButtonWidgetHelper_CyclicButtonBuilder":
		"""
		Since: 1.8.4 

		Args:
			action: the action to run when the button is pressed 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getValueToText(self) -> MethodWrapper:
		"""
		Since: 1.8.4 

		Returns:
			the function to convert a value to a text. 
		"""
		pass

	@overload
	def valueToText(self, valueToText: MethodWrapper) -> "CyclingButtonWidgetHelper_CyclicButtonBuilder":
		"""
		Since: 1.8.4 

		Args:
			valueToText: the function to convert a value to a text 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getDefaultValues(self) -> List[T]:
		"""The button will normally cycle through the default values, but if the alternate toggle is
true, it will cycle through the alternate values.\n
		Since: 1.8.4 

		Returns:
			the list of all default values. 
		"""
		pass

	@overload
	def getAlternateValues(self) -> List[T]:
		"""The button will normally cycle through the default values, but if the alternate toggle is
true, it will cycle through the alternate values.\n
		Since: 1.8.4 

		Returns:
			the list of all alternate values. 
		"""
		pass

	@overload
	def values(self, values: List[T]) -> "CyclingButtonWidgetHelper_CyclicButtonBuilder":
		"""
		Since: 1.8.4 

		Args:
			values: the default values of the button 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def alternatives(self, values: List[T]) -> "CyclingButtonWidgetHelper_CyclicButtonBuilder":
		"""
		Since: 1.8.4 

		Args:
			values: the alternate values of the button 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def values(self, defaults: List[T], alternatives: List[T]) -> "CyclingButtonWidgetHelper_CyclicButtonBuilder":
		"""
		Since: 1.8.4 

		Args:
			defaults: the default values of the button 
			alternatives: the alternate values of the button 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def values(self, defaults: List[T], alternatives: List[T]) -> "CyclingButtonWidgetHelper_CyclicButtonBuilder":
		"""
		Since: 1.8.4 

		Args:
			defaults: the default values of the button 
			alternatives: the alternate values of the button 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getAlternateToggle(self) -> MethodWrapper:
		"""
		Since: 1.8.4 

		Returns:
			the toggle function to determine if the button should cycle through the default
or the alternate values. 
		"""
		pass

	@overload
	def alternateToggle(self, alternateToggle: MethodWrapper) -> "CyclingButtonWidgetHelper_CyclicButtonBuilder":
		"""
		Since: 1.8.4 

		Args:
			alternateToggle: the toggle function to determine if the button should cycle
                       through the default or the alternate values 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def isOptionTextOmitted(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the prefix option text should be omitted, 'false' otherwise. 
		"""
		pass

	@overload
	def omitTextOption(self, optionTextOmitted: bool) -> "CyclingButtonWidgetHelper_CyclicButtonBuilder":
		"""
		Since: 1.8.4 

		Args:
			optionTextOmitted: whether the prefix option text should be omitted or not 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def createWidget(self) -> CyclingButtonWidgetHelper:
		pass

	pass





from typing import overload
from typing import TypeVar
from .RenderElement import RenderElement
from .Alignable import Alignable
from .IDraw2D import IDraw2D
from .ItemStackHelper import ItemStackHelper

net_minecraft_client_gui_DrawContext = TypeVar("net_minecraft_client_gui_DrawContext")
DrawContext = net_minecraft_client_gui_DrawContext

net_minecraft_item_ItemStack = TypeVar("net_minecraft_item_ItemStack")
ItemStack = net_minecraft_item_ItemStack


class Item(RenderElement, Alignable):
	"""
	Since: 1.0.5 
	"""
	parent: IDraw2D
	item: ItemStack
	ovText: str
	overlay: bool
	scale: float
	rotation: float
	rotateCenter: bool
	x: int
	y: int
	zIndex: int

	@overload
	def __init__(self, x: int, y: int, zIndex: int, id: str, overlay: bool, scale: float, rotation: float) -> None:
		pass

	@overload
	def __init__(self, x: int, y: int, zIndex: int, i: ItemStackHelper, overlay: bool, scale: float, rotation: float) -> None:
		pass

	@overload
	def __init__(self, x: int, y: int, zIndex: int, itemStack: ItemStackHelper, overlay: bool, scale: float, rotation: float, ovText: str) -> None:
		pass

	@overload
	def setItem(self, i: ItemStackHelper) -> "Item":
		"""
		Since: 1.0.5 [citation needed] 

		Args:
			i: 
		"""
		pass

	@overload
	def setItem(self, id: str, count: int) -> "Item":
		"""
		Since: 1.0.5 [citation needed] 

		Args:
			count: 
			id: 
		"""
		pass

	@overload
	def getItem(self) -> ItemStackHelper:
		"""
		Since: 1.0.5 [citation needed] 
		"""
		pass

	@overload
	def setX(self, x: int) -> "Item":
		"""
		Since: 1.8.4 

		Args:
			x: the new x position of this element 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getX(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the x position of this element. 
		"""
		pass

	@overload
	def setY(self, y: int) -> "Item":
		"""
		Since: 1.8.4 

		Args:
			y: the new y position of this element 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getY(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the y position of this element. 
		"""
		pass

	@overload
	def setPos(self, x: int, y: int) -> "Item":
		"""
		Since: 1.0.5 

		Args:
			x: 
			y: 
		"""
		pass

	@overload
	def setScale(self, scale: float) -> "Item":
		"""
		Since: 1.2.6 

		Args:
			scale: 
		"""
		pass

	@overload
	def getScale(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the scale of this item. 
		"""
		pass

	@overload
	def setRotation(self, rotation: float) -> "Item":
		"""
		Since: 1.2.6 

		Args:
			rotation: 
		"""
		pass

	@overload
	def getRotation(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the rotation of this item. 
		"""
		pass

	@overload
	def setRotateCenter(self, rotateCenter: bool) -> "Item":
		"""
		Since: 1.8.4 

		Args:
			rotateCenter: whether the item should be rotated around its center 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def isRotatingCenter(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this item should be rotated around its center, 'false' otherwise. 
		"""
		pass

	@overload
	def setOverlay(self, overlay: bool) -> "Item":
		"""
		Since: 1.2.0 

		Args:
			overlay: 
		"""
		pass

	@overload
	def shouldShowOverlay(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' , if the overlay, i.e. the durability bar, and the overlay text or
item count should be shown, 'false' otherwise. 
		"""
		pass

	@overload
	def setOverlayText(self, ovText: str) -> "Item":
		"""
		Since: 1.2.0 

		Args:
			ovText: 
		"""
		pass

	@overload
	def getOverlayText(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the overlay text of this item. 
		"""
		pass

	@overload
	def setZIndex(self, zIndex: int) -> "Item":
		"""
		Since: 1.8.4 

		Args:
			zIndex: the new z-index of this item 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getZIndex(self) -> int:
		pass

	@overload
	def render(self, drawContext: DrawContext, mouseX: int, mouseY: int, delta: float) -> None:
		pass

	@overload
	def render3D(self, drawContext: DrawContext, mouseX: int, mouseY: int, delta: float) -> None:
		pass

	@overload
	def render(self, drawContext: DrawContext, mouseX: int, mouseY: int, delta: float, is3dRender: bool) -> None:
		pass

	@overload
	def setParent(self, parent: IDraw2D) -> "Item":
		pass

	@overload
	def getScaledWidth(self) -> int:
		pass

	@overload
	def getParentWidth(self) -> int:
		pass

	@overload
	def getScaledHeight(self) -> int:
		pass

	@overload
	def getParentHeight(self) -> int:
		pass

	@overload
	def getScaledLeft(self) -> int:
		pass

	@overload
	def getScaledTop(self) -> int:
		pass

	@overload
	def moveTo(self, x: int, y: int) -> "Item":
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Generic
from .DonkeyEntityHelper import DonkeyEntityHelper
from .DyeColorHelper import DyeColorHelper

T = TypeVar("T")

class LlamaEntityHelper(Generic[T], DonkeyEntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: T) -> None:
		pass

	@overload
	def getVariant(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the variant of this llama. 
		"""
		pass

	@overload
	def getCarpetColor(self) -> DyeColorHelper:
		"""
		Since: 1.8.4 

		Returns:
			the color of this llama's carpet. 
		"""
		pass

	@overload
	def getStrength(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the strength of this llama. 
		"""
		pass

	@overload
	def isTraderLlama(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this llama belongs to a wandering trader, 'false' otherwise. 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Generic

T = TypeVar("T")

class RenderElementBuilder(Generic[T]):
	"""
	Since: 1.8.4 
	"""

	@overload
	def build(self) -> T:
		"""
		Since: 1.8.4 

		Returns:
			the newly created element. 
		"""
		pass

	@overload
	def buildAndAdd(self) -> T:
		"""Builds and adds the element to the draw2D the builder was created from.\n
		Since: 1.8.4 

		Returns:
			the newly created element. 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from .RenderElement import RenderElement
from .RenderElement3D import RenderElement3D
from .Draw2D import Draw2D
from .EntityHelper import EntityHelper
from .Pos3D import Pos3D
from .Pos2D import Pos2D
from .BlockPosHelper import BlockPosHelper

net_minecraft_client_gui_DrawContext = TypeVar("net_minecraft_client_gui_DrawContext")
DrawContext = net_minecraft_client_gui_DrawContext

net_minecraft_client_render_BufferBuilder = TypeVar("net_minecraft_client_render_BufferBuilder")
BufferBuilder = net_minecraft_client_render_BufferBuilder


class Surface(RenderElement, RenderElement3D, Draw2D):
	"""
	Since: 1.6.5 
	"""
	rotateToPlayer: bool
	rotateCenter: bool
	boundEntity: EntityHelper
	boundOffset: Pos3D
	pos: Pos3D
	rotations: Pos3D
	zIndexScale: float
	renderBack: bool
	cull: bool

	@overload
	def __init__(self, pos: Pos3D, rotations: Pos3D, sizes: Pos2D, minSubdivisions: int, renderBack: bool, cull: bool) -> None:
		pass

	@overload
	def setPos(self, pos: Pos3D) -> "Surface":
		"""
		Since: 1.8.4 

		Args:
			pos: the position of the surface 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def setPos(self, pos: BlockPosHelper) -> "Surface":
		"""
		Since: 1.8.4 

		Args:
			pos: the position of the surface 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def setPos(self, x: float, y: float, z: float) -> "Surface":
		pass

	@overload
	def bindToEntity(self, boundEntity: EntityHelper) -> "Surface":
		"""The surface will move with the entity at the offset location.\n
		Since: 1.8.4 

		Args:
			boundEntity: the entity to bind the surface to 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getBoundEntity(self) -> EntityHelper:
		"""
		Since: 1.8.4 

		Returns:
			the entity the surface is bound to, or 'null' if it is not bound to an
entity. 
		"""
		pass

	@overload
	def setBoundOffset(self, boundOffset: Pos3D) -> "Surface":
		"""
		Since: 1.8.4 

		Args:
			boundOffset: the offset from the entity's position to render the surface at 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def setBoundOffset(self, x: float, y: float, z: float) -> "Surface":
		"""
		Since: 1.8.4 

		Args:
			x: the x offset from the entity's position to render the surface at 
			y: the y offset from the entity's position to render the surface at 
			z: the z offset from the entity's position to render the surface at 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getBoundOffset(self) -> Pos3D:
		"""
		Since: 1.8.4 

		Returns:
			the offset from the entity's position to render the surface at. 
		"""
		pass

	@overload
	def setRotateToPlayer(self, rotateToPlayer: bool) -> "Surface":
		"""
		Since: 1.8.4 

		Args:
			rotateToPlayer: whether to rotate the surface to face the player or not 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def doesRotateToPlayer(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the surface should be rotated to face the player, 'false' otherwise. 
		"""
		pass

	@overload
	def setRotations(self, x: float, y: float, z: float) -> None:
		pass

	@overload
	def setSizes(self, x: float, y: float) -> None:
		pass

	@overload
	def getSizes(self) -> Pos2D:
		pass

	@overload
	def setMinSubdivisions(self, minSubdivisions: int) -> None:
		pass

	@overload
	def getMinSubdivisions(self) -> int:
		pass

	@overload
	def getHeight(self) -> int:
		pass

	@overload
	def getWidth(self) -> int:
		pass

	@overload
	def setRotateCenter(self, rotateCenter: bool) -> "Surface":
		"""
		Since: 1.8.4 

		Args:
			rotateCenter: whether to rotate the surface around its center or not 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def isRotatingCenter(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this surface is rotated around it's center, 'false' otherwise. 
		"""
		pass

	@overload
	def init(self) -> None:
		pass

	@overload
	def getZIndex(self) -> int:
		pass

	@overload
	def equals(self, o: object) -> bool:
		pass

	@overload
	def hashCode(self) -> int:
		pass

	@overload
	def compareToSame(self, other: "Surface") -> int:
		pass

	@overload
	def render(self, drawContext: DrawContext, builder: BufferBuilder, delta: float) -> None:
		pass

	@overload
	def render(self, drawContext: DrawContext, mouseX: int, mouseY: int, delta: float) -> None:
		pass

	pass





from typing import overload
from typing import Set
from .Core import Core
from .ServiceTrigger import ServiceTrigger
from .ServiceManager_ServiceStatus import ServiceManager_ServiceStatus
from .BaseScriptContext import BaseScriptContext
from .EventService import EventService


class ServiceManager:
	"""
	Since: 1.6.3 
	"""

	@overload
	def __init__(self, runner: Core) -> None:
		pass

	@overload
	def registerService(self, name: str, pathToFile: str) -> bool:
		"""

		Args:
			name: 
			pathToFile: relative to macro folder 

		Returns:
			false if service with that name is already registered 
		"""
		pass

	@overload
	def registerService(self, name: str, pathToFile: str, enabled: bool) -> bool:
		"""

		Args:
			name: 
			pathToFile: relative to macro folder 
			enabled: 

		Returns:
			false if service with that name is already registered 
		"""
		pass

	@overload
	def registerService(self, name: str, trigger: ServiceTrigger) -> bool:
		"""

		Args:
			name: 
			trigger: 

		Returns:
			false if service with that name already registered 
		"""
		pass

	@overload
	def unregisterService(self, name: str) -> bool:
		"""

		Args:
			name: 
		"""
		pass

	@overload
	def disableReload(self, serviceName: str) -> None:
		"""
		Since: 1.8.4 

		Args:
			serviceName: the name of the service to disable the reload feature for 
		"""
		pass

	@overload
	def renameService(self, oldName: str, newName: str) -> bool:
		"""

		Args:
			newName: 
			oldName: 

		Returns:
			false if service with new name already registered or old name doesn't exist 
		"""
		pass

	@overload
	def getServices(self) -> Set[str]:
		"""

		Returns:
			registered service names 
		"""
		pass

	@overload
	def startService(self, name: str) -> ServiceManager_ServiceStatus:
		"""starts service once

		Args:
			name: service name 

		Returns:
			previous state (or ServiceManager_ServiceStatus#UNKNOWN if unknown service) 
		"""
		pass

	@overload
	def stopService(self, name: str) -> ServiceManager_ServiceStatus:
		"""

		Args:
			name: service name 

		Returns:
			previous state (or ServiceManager_ServiceStatus#UNKNOWN if unknown service) 
		"""
		pass

	@overload
	def setAutoUnregisterKeepAlive(self, ctx: BaseScriptContext, keepAlive: bool) -> None:
		pass

	@overload
	def hasKeepAlive(self, ctx: BaseScriptContext) -> bool:
		pass

	@overload
	def restartService(self, name: str) -> ServiceManager_ServiceStatus:
		"""

		Args:
			name: service name 

		Returns:
			state before "restarting" (or ServiceManager_ServiceStatus#UNKNOWN if unknown service) 
		"""
		pass

	@overload
	def enableService(self, name: str) -> ServiceManager_ServiceStatus:
		"""

		Args:
			name: service name 

		Returns:
			previous state (or ServiceManager_ServiceStatus#UNKNOWN if unknown service) 
		"""
		pass

	@overload
	def disableService(self, name: str) -> ServiceManager_ServiceStatus:
		"""

		Args:
			name: service name 

		Returns:
			previous state (or ServiceManager_ServiceStatus#UNKNOWN if unknown service) 
		"""
		pass

	@overload
	def isRunning(self, name: str) -> bool:
		"""
		Since: 1.8.4 

		Args:
			name: the name of the service to check 

		Returns:
			'true' if the service is running, 'false' otherwise. 
		"""
		pass

	@overload
	def isEnabled(self, name: str) -> bool:
		"""
		Since: 1.8.4 

		Args:
			name: the name of the service to check 

		Returns:
			'true' if the service is enabled, 'false' otherwise. 
		"""
		pass

	@overload
	def status(self, name: str) -> ServiceManager_ServiceStatus:
		"""

		Args:
			name: service name 

		Returns:
			ServiceManager_ServiceStatus#UNKNOWN if unknown service, ServiceManager_ServiceStatus#RUNNING if disabled and running, ServiceManager_ServiceStatus#DISABLED if disabled and stopped, ServiceManager_ServiceStatus#STOPPED if enabled and stopped, ServiceManager_ServiceStatus#ENABLED if enabled and running. 
		"""
		pass

	@overload
	def getServiceData(self, name: str) -> EventService:
		"""this might throw if the service is not running...\n
		Since: 1.6.5 

		Args:
			name: 

		Returns:
			the event that is current for the service 
		"""
		pass

	@overload
	def getTrigger(self, name: str) -> ServiceTrigger:
		"""
		Since: 1.6.5 [named getServiceData previously] 

		Args:
			name: 
		"""
		pass

	@overload
	def load(self) -> None:
		"""load services from config
		"""
		pass

	@overload
	def save(self) -> None:
		"""save current registered services enabled/disabled status to config
		"""
		pass

	@overload
	def stopReloadListener(self) -> None:
		"""Stops the service manager from reloading scrips on file changes.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def startReloadListener(self) -> None:
		"""Will make the service manager reload scripts on file changes.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def markCrashed(self, serviceName: str) -> None:
		"""Mark a service as crashed so that it can be reloaded when its file changes. Crashed services
must be marked so that file change listener knows to restart them even if they are not
running because they crashed.\n
		Since: 1.8.4 

		Args:
			serviceName: the name of the service to mark as crashed 
		"""
		pass

	@overload
	def isCrashed(self, serviceName: str) -> bool:
		"""
		Since: 1.8.4 

		Args:
			serviceName: the name of the service to check 

		Returns:
			'true' if the service previously crashed, 'false' otherwise. 
		"""
		pass

	@overload
	def tickReloadListener(self) -> None:
		"""Ticks the service manager. This will check if any services need to be reloaded and reloads
them if necessary.\n
		Since: 1.8.4 
		"""
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .BaseLibrary import BaseLibrary
from .TextHelper import TextHelper
from .TextBuilder import TextBuilder
from .CommandBuilder import CommandBuilder
from .CommandNodeHelper import CommandNodeHelper
from .CommandManager import CommandManager
from .ChatHistoryManager import ChatHistoryManager

org_slf4j_Logger = TypeVar("org_slf4j_Logger")
Logger = org_slf4j_Logger


class FChat(BaseLibrary):
	"""Functions for interacting with chat. 
An instance of this class is passed to scripts as the 'Chat' variable.
	"""

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def log(self, message: object) -> None:
		"""Log to player chat.\n
		Since: 1.1.3 

		Args:
			message: 
		"""
		pass

	@overload
	def log(self, message: object, await_: bool) -> None:
		"""

		Args:
			await: should wait for message to actually be sent to chat to continue. 
			message: 
		"""
		pass

	@overload
	def logf(self, message: str, args: List[object]) -> None:
		"""Logs the formatted message to the player's chat. The message is formatted using the default
java String#format(java.lang.String,java.lang.Object...) syntax.\n
		Since: 1.8.4 

		Args:
			args: the arguments used to format the message 
			message: the message to format and log 
		"""
		pass

	@overload
	def logf(self, message: str, await_: bool, args: List[object]) -> None:
		"""Logs the formatted message to the player's chat. The message is formatted using the default
java String#format(java.lang.String,java.lang.Object...) syntax.\n
		Since: 1.8.4 

		Args:
			args: the arguments used to format the message 
			await: whether to wait for message to be sent to chat before continuing 
			message: the message to format and log 
		"""
		pass

	@overload
	def logColor(self, message: str) -> None:
		"""log with auto wrapping with FChat#ampersandToSectionSymbol(java.lang.String)\n
		Since: 1.9.0 

		Args:
			message: 
		"""
		pass

	@overload
	def logColor(self, message: str, await_: bool) -> None:
		"""log with auto wrapping with FChat#ampersandToSectionSymbol(java.lang.String)\n
		Since: 1.9.0 

		Args:
			await: 
			message: 
		"""
		pass

	@overload
	def say(self, message: str) -> None:
		"""Say to server as player.\n
		Since: 1.0.0 

		Args:
			message: 
		"""
		pass

	@overload
	def say(self, message: str, await_: bool) -> None:
		"""Say to server as player.\n
		Since: 1.3.1 

		Args:
			await: 
			message: 
		"""
		pass

	@overload
	def sayf(self, message: str, args: List[object]) -> None:
		"""Sends the formatted message to the server. The message is formatted using the default java String#format(java.lang.String,java.lang.Object...) syntax.\n
		Since: 1.8.4 

		Args:
			args: the arguments used to format the message 
			message: the message to format and send to the server 
		"""
		pass

	@overload
	def sayf(self, message: str, await_: bool, args: List[object]) -> None:
		"""Sends the formatted message to the server. The message is formatted using the default java String#format(java.lang.String,java.lang.Object...) syntax.\n
		Since: 1.8.4 

		Args:
			args: the arguments used to format the message 
			await: whether to wait for message to be sent to chat before continuing 
			message: the message to format and send to the server 
		"""
		pass

	@overload
	def open(self, message: str) -> None:
		"""open the chat input box with specific text already typed.\n
		Since: 1.6.4 

		Args:
			message: the message to start the chat screen with 
		"""
		pass

	@overload
	def open(self, message: str, await_: bool) -> None:
		"""open the chat input box with specific text already typed.
hint: you can combine with FJsMacros#waitForEvent(java.lang.String) or FJsMacros#once(java.lang.String,xyz.wagyourtail.jsmacros.core.MethodWrapper<xyz.wagyourtail.jsmacros.core.event.BaseEvent,xyz.wagyourtail.jsmacros.core.language.EventContainer<?>,java.lang.Object,?>) to wait for the chat screen
to close and/or the to wait for the sent message\n
		Since: 1.6.4 

		Args:
			await: 
			message: the message to start the chat screen with 
		"""
		pass

	@overload
	def title(self, title: object, subtitle: object, fadeIn: int, remain: int, fadeOut: int) -> None:
		"""Display a Title to the player.\n
		Since: 1.2.1 

		Args:
			fadeOut: 
			fadeIn: 
			remain: 
			subtitle: 
			title: 
		"""
		pass

	@overload
	def actionbar(self, text: object) -> None:
		"""
		Since: 1.8.1 

		Args:
			text: 
		"""
		pass

	@overload
	def actionbar(self, text: object, tinted: bool) -> None:
		"""Display the smaller title that's above the actionbar.\n
		Since: 1.2.1 

		Args:
			tinted: 
			text: 
		"""
		pass

	@overload
	def toast(self, title: object, desc: object) -> None:
		"""Display a toast.\n
		Since: 1.2.5 

		Args:
			title: 
			desc: 
		"""
		pass

	@overload
	def createTextHelperFromString(self, content: str) -> TextHelper:
		"""Creates a TextHelper for use where you need one and not a string.\n
		Since: 1.1.3 

		Args:
			content: 

		Returns:
			a new TextHelper 
		"""
		pass

	@overload
	def createTextHelperFromTranslationKey(self, key: str, content: List[object]) -> TextHelper:
		"""
		Since: 1.9.0 

		Returns:
			a new TextHelper 
		"""
		pass

	@overload
	def getLogger(self) -> Logger:
		"""
		Since: 1.5.2 
		"""
		pass

	@overload
	def getLogger(self, name: str) -> Logger:
		"""returns a log4j logger, for logging to console only.\n
		Since: 1.5.2 

		Args:
			name: 
		"""
		pass

	@overload
	def createTextHelperFromJSON(self, json: str) -> TextHelper:
		"""Create a TextHelper for use where you need one and not a string.\n
		Since: 1.1.3 

		Args:
			json: 

		Returns:
			a new TextHelper 
		"""
		pass

	@overload
	def createTextBuilder(self) -> TextBuilder:
		"""
		Since: 1.3.0 

		Returns:
			a new builder 
		"""
		pass

	@overload
	def createCommandBuilder(self, name: str) -> CommandBuilder:
		"""
		Since: 1.4.2 

		Args:
			name: name of command 
		"""
		pass

	@overload
	def unregisterCommand(self, name: str) -> CommandNodeHelper:
		"""
		Since: 1.6.5 

		Args:
			name: 
		"""
		pass

	@overload
	def reRegisterCommand(self, node: CommandNodeHelper) -> None:
		"""
		Since: 1.6.5 

		Args:
			node: 
		"""
		pass

	@overload
	def getCommandManager(self) -> CommandManager:
		"""
		Since: 1.7.0 
		"""
		pass

	@overload
	def getHistory(self) -> ChatHistoryManager:
		"""
		Since: 1.7.0 
		"""
		pass

	@overload
	def getTextWidth(self, text: str) -> int:
		"""
		Since: 1.8.4 

		Args:
			text: the text to get the width of 

		Returns:
			the width of the given text in pixels. 
		"""
		pass

	@overload
	def sectionSymbolToAmpersand(self, string: str) -> str:
		"""escapes to since 1.9.0\n
		Since: 1.6.5 

		Args:
			string: 

		Returns:
			-> 
		"""
		pass

	@overload
	def ampersandToSectionSymbol(self, string: str) -> str:
		"""escapes to since 1.9.0\n
		Since: 1.6.5 

		Args:
			string: 

		Returns:
			-> 
		"""
		pass

	@overload
	def stripFormatting(self, string: str) -> str:
		"""
		Since: 1.6.5 

		Args:
			string: 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from .AnimalEntityHelper import AnimalEntityHelper
from .EntityHelper import EntityHelper

net_minecraft_entity_passive_FrogEntity = TypeVar("net_minecraft_entity_passive_FrogEntity")
FrogEntity = net_minecraft_entity_passive_FrogEntity


class FrogEntityHelper(AnimalEntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: FrogEntity) -> None:
		pass

	@overload
	def getVariant(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the variant of this frog. 
		"""
		pass

	@overload
	def getTarget(self) -> EntityHelper:
		"""
		Since: 1.8.4 

		Returns:
			the target of this frog, or 'null' if it has none. 
		"""
		pass

	@overload
	def isCroaking(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this frog is croaking, 'false' otherwise. 
		"""
		pass

	pass





from typing import overload
from .NBTElementHelper import NBTElementHelper


class NBTElementHelper_NBTNumberHelper(NBTElementHelper):
	"""
	Since: 1.5.1 
	"""

	@overload
	def asLong(self) -> float:
		"""
		Since: 1.5.1 
		"""
		pass

	@overload
	def asInt(self) -> int:
		"""
		Since: 1.5.1 
		"""
		pass

	@overload
	def asShort(self) -> float:
		"""
		Since: 1.5.1 
		"""
		pass

	@overload
	def asByte(self) -> float:
		"""
		Since: 1.5.1 
		"""
		pass

	@overload
	def asFloat(self) -> float:
		"""
		Since: 1.5.1 
		"""
		pass

	@overload
	def asDouble(self) -> float:
		"""
		Since: 1.5.1 
		"""
		pass

	@overload
	def asNumber(self) -> Number:
		"""
		Since: 1.5.1 
		"""
		pass

	pass


